verbform = [
{'lemma': 'abandon', 'vbz': 'abandons', 'vbd': 'abandoned', 'vbn': 'abandoned', 'vbg': 'abandoning'},
{'lemma': 'absorb', 'vbz': 'absorbs', 'vbd': 'absorbed', 'vbn': 'absorbed', 'vbg': 'absorbing'},
{'lemma': 'abuse', 'vbz': 'abuses', 'vbd': 'abused', 'vbn': 'abused', 'vbg': 'abusing'},
{'lemma': 'accept', 'vbz': 'accepts', 'vbd': 'accepted', 'vbn': 'accepted', 'vbg': 'accepting'},
{'lemma': 'access', 'vbz': 'accesses', 'vbd': 'accessed', 'vbn': 'accessed', 'vbg': 'accessing'},
{'lemma': 'accompany', 'vbz': 'accompanies', 'vbd': 'accompanied', 'vbn': 'accompanied', 'vbg': 'accompanying'},
{'lemma': 'account', 'vbz': 'accounts', 'vbd': 'accounted', 'vbn': 'accounted', 'vbg': 'accounting'},
{'lemma': 'accuse', 'vbz': 'accuses', 'vbd': 'accused', 'vbn': 'accused', 'vbg': 'accusing'},
{'lemma': 'achieve', 'vbz': 'achieves', 'vbd': 'achieved', 'vbn': 'achieved', 'vbg': 'achieving'},
{'lemma': 'acknowledge', 'vbz': 'acknowledges', 'vbd': 'acknowledged', 'vbn': 'acknowledged', 'vbg': 'acknowledging'},
{'lemma': 'acquire', 'vbz': 'acquires', 'vbd': 'acquired', 'vbn': 'acquired', 'vbg': 'acquiring'},
{'lemma': 'act', 'vbz': 'acts', 'vbd': 'acted', 'vbn': 'acted', 'vbg': 'acting'},
{'lemma': 'adapt', 'vbz': 'adapts', 'vbd': 'adapted', 'vbn': 'adapted', 'vbg': 'adapting'},
{'lemma': 'add', 'vbz': 'adds', 'vbd': 'added', 'vbn': 'added', 'vbg': 'adding'},
{'lemma': 'address', 'vbz': 'addresses', 'vbd': 'addressed', 'vbn': 'addressed', 'vbg': 'addressing'},
{'lemma': 'adjust', 'vbz': 'adjusts', 'vbd': 'adjusted', 'vbn': 'adjusted', 'vbg': 'adjusting'},
{'lemma': 'admire', 'vbz': 'admires', 'vbd': 'admired', 'vbn': 'admired', 'vbg': 'admiring'},
{'lemma': 'admit', 'vbz': 'admits', 'vbd': 'admited', 'vbn': 'admited', 'vbg': 'admiting'},
{'lemma': 'adopt', 'vbz': 'adopts', 'vbd': 'adopted', 'vbn': 'adopted', 'vbg': 'adopting'},
{'lemma': 'advance', 'vbz': 'advances', 'vbd': 'advanced', 'vbn': 'advanced', 'vbg': 'advancing'},
{'lemma': 'advantage', 'vbz': 'advantages', 'vbd': 'advantaged', 'vbn': 'advantaged', 'vbg': 'advantaging'},
{'lemma': 'advert', 'vbz': 'adverts', 'vbd': 'adverted', 'vbn': 'adverted', 'vbg': 'adverting'},
{'lemma': 'advise', 'vbz': 'advises', 'vbd': 'advised', 'vbn': 'advised', 'vbg': 'advising'},

{'lemma': 'effect', 'vbz': 'effects', 'vbd': 'effected', 'vbn': 'effected', 'vbg': 'effecting'},
{'lemma': 'efford', 'vbz': 'effords', 'vbd': 'efforded', 'vbn': 'efforded', 'vbg': 'effording'},
{'lemma': 'affect', 'vbz': 'affects', 'vbd': 'affected', 'vbn': 'affected', 'vbg': 'affecting'},
{'lemma': 'afford', 'vbz': 'affords', 'vbd': 'afforded', 'vbn': 'afforded', 'vbg': 'affording'},

{'lemma': 'agree', 'vbz': 'agrees', 'vbd': 'agreed', 'vbn': 'agreed', 'vbg': 'agreeing'},
{'lemma': 'aim', 'vbz': 'aims', 'vbd': 'aimed', 'vbn': 'aimed', 'vbg': 'aiming'},
{'lemma': 'air', 'vbz': 'airs', 'vbd': 'aired', 'vbn': 'aired', 'vbg': 'airing'},
{'lemma': 'alarm', 'vbz': 'alarms', 'vbd': 'alarmed', 'vbn': 'alarmed', 'vbg': 'alarming'},
{'lemma': 'allow', 'vbz': 'allows', 'vbd': 'allowed', 'vbn': 'allowed', 'vbg': 'allowing'},
{'lemma': 'alter', 'vbz': 'alters', 'vbd': 'altered', 'vbn': 'altered', 'vbg': 'altering'},
{'lemma': 'amount', 'vbz': 'amounts', 'vbd': 'amounted', 'vbn': 'amounted', 'vbg': 'amounting'},
{'lemma': 'analyse', 'vbz': 'analyses', 'vbd': 'analysed', 'vbn': 'analysed', 'vbg': 'analysing'},
{'lemma': 'angle', 'vbz': 'angles', 'vbd': 'angled', 'vbn': 'angled', 'vbg': 'angling'},
{'lemma': 'announce', 'vbz': 'announces', 'vbd': 'announced', 'vbn': 'announced', 'vbg': 'announcing'},
{'lemma': 'annoy', 'vbz': 'annoys', 'vbd': 'annoyed', 'vbn': 'annoyed', 'vbg': 'annoying'},
{'lemma': 'answer', 'vbz': 'answers', 'vbd': 'answered', 'vbn': 'answered', 'vbg': 'answering'},
{'lemma': 'anticipate', 'vbz': 'anticipates', 'vbd': 'anticipated', 'vbn': 'anticipated', 'vbg': 'anticipating'},
{'lemma': 'apologize', 'vbz': 'apologizes', 'vbd': 'apologized', 'vbn': 'apologized', 'vbg': 'apologizing'},
{'lemma': 'appeal', 'vbz': 'appeals', 'vbd': 'appealed', 'vbn': 'appealed', 'vbg': 'appealing'},
{'lemma': 'appear', 'vbz': 'appears', 'vbd': 'appeared', 'vbn': 'appeared', 'vbg': 'appearing'},
{'lemma': 'apply', 'vbz': 'applies', 'vbd': 'applied', 'vbn': 'applied', 'vbg': 'applying'},
{'lemma': 'appoint', 'vbz': 'appoints', 'vbd': 'appointed', 'vbn': 'appointed', 'vbg': 'appointing'},
{'lemma': 'appreciate', 'vbz': 'appreciates', 'vbd': 'appreciated', 'vbn': 'appreciated', 'vbg': 'appreciating'},
{'lemma': 'approach', 'vbz': 'approaches', 'vbd': 'approached', 'vbn': 'approached', 'vbg': 'approaching'},
{'lemma': 'appropriate', 'vbz': 'appropriates', 'vbd': 'appropriated', 'vbn': 'appropriated', 'vbg': 'appropriating'},
{'lemma': 'approve', 'vbz': 'approves', 'vbd': 'approved', 'vbn': 'approved', 'vbg': 'approving'},
{'lemma': 'approximate', 'vbz': 'approximates', 'vbd': 'approximated', 'vbn': 'approximated', 'vbg': 'approximating'},
{'lemma': 'argue', 'vbz': 'argues', 'vbd': 'argued', 'vbn': 'argued', 'vbg': 'arguing'},
{'lemma': 'argument', 'vbz': 'arguments', 'vbd': 'argumented', 'vbn': 'argumented', 'vbg': 'argumenting'},
{'lemma': 'arise', 'vbz': 'arises', 'vbd': 'arised', 'vbn': 'arised', 'vbg': 'arising'},
{'lemma': 'arrange', 'vbz': 'arranges', 'vbd': 'arranged', 'vbn': 'arranged', 'vbg': 'arranging'},
{'lemma': 'arrest', 'vbz': 'arrests', 'vbd': 'arrested', 'vbn': 'arrested', 'vbg': 'arresting'},
{'lemma': 'arrive', 'vbz': 'arrives', 'vbd': 'arrived', 'vbn': 'arrived', 'vbg': 'arriving'},
{'lemma': 'article', 'vbz': 'articles', 'vbd': 'articled', 'vbn': 'articled', 'vbg': 'articling'},
{'lemma': 'ask', 'vbz': 'asks', 'vbd': 'asked', 'vbn': 'asked', 'vbg': 'asking'},
{'lemma': 'assess', 'vbz': 'assesses', 'vbd': 'assessed', 'vbn': 'assessed', 'vbg': 'assessing'},
{'lemma': 'assist', 'vbz': 'assists', 'vbd': 'assisted', 'vbn': 'assisted', 'vbg': 'assisting'},
{'lemma': 'associate', 'vbz': 'associates', 'vbd': 'associated', 'vbn': 'associated', 'vbg': 'associating'},
{'lemma': 'assume', 'vbz': 'assumes', 'vbd': 'assumed', 'vbn': 'assumed', 'vbg': 'assuming'},
{'lemma': 'assure', 'vbz': 'assures', 'vbd': 'assured', 'vbn': 'assured', 'vbg': 'assuring'},
{'lemma': 'attach', 'vbz': 'attaches', 'vbd': 'attached', 'vbn': 'attached', 'vbg': 'attaching'},
{'lemma': 'attack', 'vbz': 'attacks', 'vbd': 'attacked', 'vbn': 'attacked', 'vbg': 'attacking'},
{'lemma': 'attend', 'vbz': 'attends', 'vbd': 'attended', 'vbn': 'attended', 'vbg': 'attending'},
{'lemma': 'attract', 'vbz': 'attracts', 'vbd': 'attracted', 'vbn': 'attracted', 'vbg': 'attracting'},
{'lemma': 'avoid', 'vbz': 'avoids', 'vbd': 'avoided', 'vbn': 'avoided', 'vbg': 'avoiding'},
{'lemma': 'awake', 'vbz': 'awakes', 'vbd': 'awaked', 'vbn': 'awaked', 'vbg': 'awaking'},
{'lemma': 'award', 'vbz': 'awards', 'vbd': 'awarded', 'vbn': 'awarded', 'vbg': 'awarding'},
{'lemma': 'bake', 'vbz': 'bakes', 'vbd': 'baked', 'vbn': 'baked', 'vbg': 'baking'},
{'lemma': 'balance', 'vbz': 'balances', 'vbd': 'balanced', 'vbn': 'balanced', 'vbg': 'balancing'},
{'lemma': 'ban', 'vbz': 'bans', 'vbd': 'banned', 'vbn': 'banned', 'vbg': 'banning'},
{'lemma': 'band', 'vbz': 'bands', 'vbd': 'banded', 'vbn': 'banded', 'vbg': 'banding'},
{'lemma': 'bang', 'vbz': 'bangs', 'vbd': 'banged', 'vbn': 'banged', 'vbg': 'banging'},
{'lemma': 'bar', 'vbz': 'bars', 'vbd': 'barred', 'vbn': 'barred', 'vbg': 'baring'},
{'lemma': 'base', 'vbz': 'bases', 'vbd': 'based', 'vbn': 'based', 'vbg': 'basing'},
{'lemma': 'bat', 'vbz': 'bats', 'vbd': 'batted', 'vbn': 'batted', 'vbg': 'bating'},
{'lemma': 'bath', 'vbz': 'baths', 'vbd': 'bathed', 'vbn': 'bathed', 'vbg': 'bathing'},
{'lemma': 'battle', 'vbz': 'battles', 'vbd': 'battled', 'vbn': 'battled', 'vbg': 'battling'},
{'lemma': 'beach', 'vbz': 'beaches', 'vbd': 'beached', 'vbn': 'beached', 'vbg': 'beaching'},
{'lemma': 'bear', 'vbz': 'bears', 'vbd': 'beared', 'vbn': 'beared', 'vbg': 'bearing'},
{'lemma': 'beard', 'vbz': 'beards', 'vbd': 'bearded', 'vbn': 'bearded', 'vbg': 'bearding'},
{'lemma': 'become', 'vbz': 'becomes', 'vbd': 'became', 'vbn': 'become', 'vbg': 'becoming'},
{'lemma': 'begin', 'vbz': 'begins', 'vbd': 'began', 'vbn': 'began', 'vbg': 'beginning'},
{'lemma': 'behave', 'vbz': 'behaves', 'vbd': 'behaved', 'vbn': 'behaved', 'vbg': 'behaving'},
{'lemma': 'believe', 'vbz': 'believes', 'vbd': 'believed', 'vbn': 'believed', 'vbg': 'believing'},
{'lemma': 'belong', 'vbz': 'belongs', 'vbd': 'belonged', 'vbn': 'belonged', 'vbg': 'belonging'},
{'lemma': 'bend', 'vbz': 'bends', 'vbd': 'bent', 'vbn': 'bent', 'vbg': 'bending'},
{'lemma': 'benefit', 'vbz': 'benefits', 'vbd': 'benefited', 'vbn': 'benefited', 'vbg': 'benefiting'},
{'lemma': 'bet', 'vbz': 'bets', 'vbd': 'bet', 'vbn': 'bet', 'vbg': 'betting'},
{'lemma': 'better', 'vbz': 'betters', 'vbd': 'bettered', 'vbn': 'bettered', 'vbg': 'bettering'},
{'lemma': 'bicycle', 'vbz': 'bicycles', 'vbd': 'bicycled', 'vbn': 'bicycled', 'vbg': 'bicycling'},
{'lemma': 'bid', 'vbz': 'bids', 'vbd': 'bid/bidden', 'vbn': 'bid/bidden', 'vbg': 'bidding'},
{'lemma': 'bike', 'vbz': 'bikes', 'vbd': 'biked', 'vbn': 'biked', 'vbg': 'biking'},
{'lemma': 'bill', 'vbz': 'bills', 'vbd': 'billed', 'vbn': 'billed', 'vbg': 'billing'},
{'lemma': 'bite', 'vbz': 'bites', 'vbd': 'bit', 'vbn': 'bitten', 'vbg': 'biting'},
{'lemma': 'blame', 'vbz': 'blames', 'vbd': 'blamed', 'vbn': 'blamed', 'vbg': 'blaming'},
{'lemma': 'bless', 'vbz': 'blesses', 'vbd': 'blessed', 'vbn': 'blessed', 'vbg': 'blessing'},
{'lemma': 'blind', 'vbz': 'blinds', 'vbd': 'blinded', 'vbn': 'blinded', 'vbg': 'blinding'},
{'lemma': 'block', 'vbz': 'blocks', 'vbd': 'blocked', 'vbn': 'blocked', 'vbg': 'blocking'},
{'lemma': 'blood', 'vbz': 'bloods', 'vbd': 'blooded', 'vbn': 'blooded', 'vbg': 'blooding'},
{'lemma': 'blow', 'vbz': 'blows', 'vbd': 'blew', 'vbn': 'blown', 'vbg': 'blowing'},
{'lemma': 'blue', 'vbz': 'blues', 'vbd': 'blued', 'vbn': 'blued', 'vbg': 'bluing'},
{'lemma': 'board', 'vbz': 'boards', 'vbd': 'boarded', 'vbn': 'boarded', 'vbg': 'boarding'},
{'lemma': 'boat', 'vbz': 'boats', 'vbd': 'boated', 'vbn': 'boated', 'vbg': 'boating'},
{'lemma': 'boil', 'vbz': 'boils', 'vbd': 'boiled', 'vbn': 'boiled', 'vbg': 'boiling'},
{'lemma': 'bomb', 'vbz': 'bombs', 'vbd': 'bombed', 'vbn': 'bombed', 'vbg': 'bombing'},
{'lemma': 'book', 'vbz': 'books', 'vbd': 'booked', 'vbn': 'booked', 'vbg': 'booking'},
{'lemma': 'boot', 'vbz': 'boots', 'vbd': 'booted', 'vbn': 'booted', 'vbg': 'booting'},
{'lemma': 'borrow', 'vbz': 'borrows', 'vbd': 'borrowed', 'vbn': 'borrowed', 'vbg': 'borrowing'},
{'lemma': 'boss', 'vbz': 'bosses', 'vbd': 'bossed', 'vbn': 'bossed', 'vbg': 'bossing'},
{'lemma': 'bother', 'vbz': 'bothers', 'vbd': 'bothered', 'vbn': 'bothered', 'vbg': 'bothering'},
{'lemma': 'bounce', 'vbz': 'bounces', 'vbd': 'bounced', 'vbn': 'bounced', 'vbg': 'bouncing'},
{'lemma': 'bound', 'vbz': 'bounds', 'vbd': 'bounded', 'vbn': 'bounded', 'vbg': 'bounding'},
{'lemma': 'bowl', 'vbz': 'bowls', 'vbd': 'bowled', 'vbn': 'bowled', 'vbg': 'bowling'},
{'lemma': 'branch', 'vbz': 'branches', 'vbd': 'branched', 'vbn': 'branched', 'vbg': 'branching'},
{'lemma': 'brave', 'vbz': 'braves', 'vbd': 'braved', 'vbn': 'braved', 'vbg': 'braving'},
{'lemma': 'break', 'vbz': 'breaks', 'vbd': 'broke', 'vbn': 'broken', 'vbg': 'breaking'},
{'lemma': 'breast', 'vbz': 'breasts', 'vbd': 'breasted', 'vbn': 'breasted', 'vbg': 'breasting'},
{'lemma': 'breathe', 'vbz': 'breathes', 'vbd': 'breathed', 'vbn': 'breathed', 'vbg': 'breathing'},
{'lemma': 'brick', 'vbz': 'bricks', 'vbd': 'bricked', 'vbn': 'bricked', 'vbg': 'bricking'},
{'lemma': 'bridge', 'vbz': 'bridges', 'vbd': 'bridged', 'vbn': 'bridged', 'vbg': 'bridging'},
{'lemma': 'bring', 'vbz': 'brings', 'vbd': 'brought', 'vbn': 'brought', 'vbg': 'bringing'},
{'lemma': 'brush', 'vbz': 'brushes', 'vbd': 'brushed', 'vbn': 'brushed', 'vbg': 'brushing'},
{'lemma': 'buck', 'vbz': 'bucks', 'vbd': 'bucked', 'vbn': 'bucked', 'vbg': 'bucking'},
{'lemma': 'bucket', 'vbz': 'buckets', 'vbd': 'bucketed', 'vbn': 'bucketed', 'vbg': 'bucketing'},
{'lemma': 'budget', 'vbz': 'budgets', 'vbd': 'budgeted', 'vbn': 'budgeted', 'vbg': 'budgeting'},
{'lemma': 'bug', 'vbz': 'bugs', 'vbd': 'bugged', 'vbn': 'bugged', 'vbg': 'bugging'},
{'lemma': 'build', 'vbz': 'builds', 'vbd': 'built', 'vbn': 'built', 'vbg': 'building'},
{'lemma': 'bump', 'vbz': 'bumps', 'vbd': 'bumped', 'vbn': 'bumped', 'vbg': 'bumping'},
{'lemma': 'bunch', 'vbz': 'bunches', 'vbd': 'bunched', 'vbn': 'bunched', 'vbg': 'bunching'},
{'lemma': 'burn', 'vbz': 'burns', 'vbd': 'burned', 'vbn': 'burned', 'vbg': 'burning'},
{'lemma': 'burst', 'vbz': 'bursts', 'vbd': 'bursted', 'vbn': 'bursted', 'vbg': 'bursting'},
{'lemma': 'bury', 'vbz': 'buries', 'vbd': 'buried', 'vbn': 'buried', 'vbg': 'burying'},
{'lemma': 'butcher', 'vbz': 'butchers', 'vbd': 'butchered', 'vbn': 'butchered', 'vbg': 'butchering'},
{'lemma': 'butter', 'vbz': 'butters', 'vbd': 'buttered', 'vbn': 'buttered', 'vbg': 'buttering'},
{'lemma': 'button', 'vbz': 'buttons', 'vbd': 'buttoned', 'vbn': 'buttoned', 'vbg': 'buttoning'},
{'lemma': 'buy', 'vbz': 'buys', 'vbd': 'bought', 'vbn': 'bought', 'vbg': 'buying'},
{'lemma': 'cable', 'vbz': 'cables', 'vbd': 'cabled', 'vbn': 'cabled', 'vbg': 'cabling'},
{'lemma': 'calculate', 'vbz': 'calculates', 'vbd': 'calculated', 'vbn': 'calculated', 'vbg': 'calculating'},
{'lemma': 'calendar', 'vbz': 'calendars', 'vbd': 'calendared', 'vbn': 'calendared', 'vbg': 'calendaring'},
{'lemma': 'call', 'vbz': 'calls', 'vbd': 'called', 'vbn': 'called', 'vbg': 'calling'},
{'lemma': 'calm', 'vbz': 'calms', 'vbd': 'calmed', 'vbn': 'calmed', 'vbg': 'calming'},
{'lemma': 'camp', 'vbz': 'camps', 'vbd': 'camped', 'vbn': 'camped', 'vbg': 'camping'},
{'lemma': 'campaign', 'vbz': 'campaigns', 'vbd': 'campaigned', 'vbn': 'campaigned', 'vbg': 'campaigning'},
{'lemma': 'cancel', 'vbz': 'cancels', 'vbd': 'canceled', 'vbn': 'canceled', 'vbg': 'canceling'},
{'lemma': 'candy', 'vbz': 'candies', 'vbd': 'candied', 'vbn': 'candied', 'vbg': 'candying'},
{'lemma': 'cap', 'vbz': 'caps', 'vbd': 'capped', 'vbn': 'capped', 'vbg': 'capping'},
{'lemma': 'captain', 'vbz': 'captains', 'vbd': 'captained', 'vbn': 'captained', 'vbg': 'captaining'},
{'lemma': 'capture', 'vbz': 'captures', 'vbd': 'captured', 'vbn': 'captured', 'vbg': 'capturing'},
{'lemma': 'care', 'vbz': 'cares', 'vbd': 'cared', 'vbn': 'cared', 'vbg': 'caring'},
{'lemma': 'carpet', 'vbz': 'carpets', 'vbd': 'carpeted', 'vbn': 'carpeted', 'vbg': 'carpeting'},
{'lemma': 'carry', 'vbz': 'carries', 'vbd': 'carried', 'vbn': 'carried', 'vbg': 'carrying'},
{'lemma': 'cash', 'vbz': 'cashes', 'vbd': 'cashed', 'vbn': 'cashed', 'vbg': 'cashing'},
{'lemma': 'cast', 'vbz': 'casts', 'vbd': 'casted', 'vbn': 'casted', 'vbg': 'casting'},
{'lemma': 'catch', 'vbz': 'catches', 'vbd': 'caught', 'vbn': 'caught', 'vbg': 'catching'},
{'lemma': 'cause', 'vbz': 'causes', 'vbd': 'caused', 'vbn': 'caused', 'vbg': 'causing'},
{'lemma': 'cease', 'vbz': 'ceases', 'vbd': 'ceased', 'vbn': 'ceased', 'vbg': 'ceasing'},
{'lemma': 'celebrate', 'vbz': 'celebrates', 'vbd': 'celebrated', 'vbn': 'celebrated', 'vbg': 'celebrating'},
{'lemma': 'challenge', 'vbz': 'challenges', 'vbd': 'challenged', 'vbn': 'challenged', 'vbg': 'challenging'},
{'lemma': 'change', 'vbz': 'changes', 'vbd': 'changed', 'vbn': 'changed', 'vbg': 'changing'},
{'lemma': 'characterize', 'vbz': 'characterizes', 'vbd': 'characterized', 'vbn': 'characterized', 'vbg': 'characterizing'},
{'lemma': 'charge', 'vbz': 'charges', 'vbd': 'charged', 'vbn': 'charged', 'vbg': 'charging'},
{'lemma': 'chase', 'vbz': 'chases', 'vbd': 'chased', 'vbn': 'chased', 'vbg': 'chasing'},
{'lemma': 'cheat', 'vbz': 'cheats', 'vbd': 'cheated', 'vbn': 'cheated', 'vbg': 'cheating'},
{'lemma': 'check', 'vbz': 'checks', 'vbd': 'checked', 'vbn': 'checked', 'vbg': 'checking'},
{'lemma': 'choose', 'vbz': 'chooses', 'vbd': 'chose', 'vbn': 'chosen', 'vbg': 'choosing'},
{'lemma': 'chop', 'vbz': 'chops', 'vbd': 'choopped', 'vbn': 'choopped', 'vbg': 'chopping'},
{'lemma': 'chuck', 'vbz': 'chucks', 'vbd': 'chucked', 'vbn': 'chucked', 'vbg': 'chucking'},
{'lemma': 'claim', 'vbz': 'claims', 'vbd': 'claimed', 'vbn': 'claimed', 'vbg': 'claiming'},
{'lemma': 'clear', 'vbz': 'clears', 'vbd': 'cleared', 'vbn': 'cleared', 'vbg': 'clearing'},
{'lemma': 'clerk', 'vbz': 'clerks', 'vbd': 'clerked', 'vbn': 'clerked', 'vbg': 'clerking'},
{'lemma': 'click', 'vbz': 'clicks', 'vbd': 'clicked', 'vbn': 'clicked', 'vbg': 'clicking'},
{'lemma': 'climb', 'vbz': 'climbs', 'vbd': 'climbed', 'vbn': 'climbed', 'vbg': 'climbing'},
{'lemma': 'clock', 'vbz': 'clocks', 'vbd': 'clocked', 'vbn': 'clocked', 'vbg': 'clocking'},
{'lemma': 'close', 'vbz': 'closes', 'vbd': 'closed', 'vbn': 'closed', 'vbg': 'closing'},
{'lemma': 'closet', 'vbz': 'closets', 'vbd': 'closeted', 'vbn': 'closeted', 'vbg': 'closeting'},
{'lemma': 'cloud', 'vbz': 'clouds', 'vbd': 'clouded', 'vbn': 'clouded', 'vbg': 'clouding'},
{'lemma': 'clue', 'vbz': 'clues', 'vbd': 'clued', 'vbn': 'clued', 'vbg': 'cluing'},
{'lemma': 'coach', 'vbz': 'coaches', 'vbd': 'coached', 'vbn': 'coached', 'vbg': 'coaching'},
{'lemma': 'coal', 'vbz': 'coals', 'vbd': 'coaled', 'vbn': 'coaled', 'vbg': 'coaling'},
{'lemma': 'coast', 'vbz': 'coasts', 'vbd': 'coasted', 'vbn': 'coasted', 'vbg': 'coasting'},
{'lemma': 'coat', 'vbz': 'coats', 'vbd': 'coated', 'vbn': 'coated', 'vbg': 'coating'},
{'lemma': 'code', 'vbz': 'codes', 'vbd': 'coded', 'vbn': 'coded', 'vbg': 'coding'},
{'lemma': 'coin', 'vbz': 'coins', 'vbd': 'coined', 'vbn': 'coined', 'vbg': 'coining'},
{'lemma': 'collapse', 'vbz': 'collapses', 'vbd': 'collapsed', 'vbn': 'collapsed', 'vbg': 'collapsing'},
{'lemma': 'collar', 'vbz': 'collars', 'vbd': 'collared', 'vbn': 'collared', 'vbg': 'collaring'},
{'lemma': 'collect', 'vbz': 'collects', 'vbd': 'collected', 'vbn': 'collected', 'vbg': 'collecting'},
{'lemma': 'colour', 'vbz': 'colours', 'vbd': 'coloured', 'vbn': 'coloured', 'vbg': 'colouring'},
{'lemma': 'combine', 'vbz': 'combines', 'vbd': 'combined', 'vbn': 'combined', 'vbg': 'combining'},
{'lemma': 'come', 'vbz': 'comes', 'vbd': 'came', 'vbn': 'come', 'vbg': 'coming'},
{'lemma': 'command', 'vbz': 'commands', 'vbd': 'commanded', 'vbn': 'commanded', 'vbg': 'commanding'},
{'lemma': 'comment', 'vbz': 'comments', 'vbd': 'commented', 'vbn': 'commented', 'vbg': 'commenting'},
{'lemma': 'commission', 'vbz': 'commissions', 'vbd': 'commissioned', 'vbn': 'commissioned', 'vbg': 'commissioning'},
{'lemma': 'commit', 'vbz': 'commits', 'vbd': 'commited', 'vbn': 'commited', 'vbg': 'commiting'},
{'lemma': 'communicate', 'vbz': 'communicates', 'vbd': 'communicated', 'vbn': 'communicated', 'vbg': 'communicating'},
{'lemma': 'compare', 'vbz': 'compares', 'vbd': 'compared', 'vbn': 'compared', 'vbg': 'comparing'},
{'lemma': 'compete', 'vbz': 'competes', 'vbd': 'competed', 'vbn': 'competed', 'vbg': 'competing'},
{'lemma': 'complain', 'vbz': 'complains', 'vbd': 'complained', 'vbn': 'complained', 'vbg': 'complaining'},
{'lemma': 'complete', 'vbz': 'completes', 'vbd': 'completed', 'vbn': 'completed', 'vbg': 'completing'},
{'lemma': 'complicated', 'vbz': 'complicateds', 'vbd': 'complicateded', 'vbn': 'complicateded', 'vbg': 'complicateding'},
{'lemma': 'comprise', 'vbz': 'comprises', 'vbd': 'comprised', 'vbn': 'comprised', 'vbg': 'comprising'},
{'lemma': 'concentrate', 'vbz': 'concentrates', 'vbd': 'concentrated', 'vbn': 'concentrated', 'vbg': 'concentrating'},
{'lemma': 'concern', 'vbz': 'concerns', 'vbd': 'concerned', 'vbn': 'concerned', 'vbg': 'concerning'},
{'lemma': 'concert', 'vbz': 'concerts', 'vbd': 'concerted', 'vbn': 'concerted', 'vbg': 'concerting'},
{'lemma': 'conclude', 'vbz': 'concludes', 'vbd': 'concluded', 'vbn': 'concluded', 'vbg': 'concluding'},
{'lemma': 'condition', 'vbz': 'conditions', 'vbd': 'conditioned', 'vbn': 'conditioned', 'vbg': 'conditioning'},
{'lemma': 'conduct', 'vbz': 'conducts', 'vbd': 'conducted', 'vbn': 'conducted', 'vbg': 'conducting'},
{'lemma': 'confine', 'vbz': 'confines', 'vbd': 'confined', 'vbn': 'confined', 'vbg': 'confining'},
{'lemma': 'confirm', 'vbz': 'confirms', 'vbd': 'confirmed', 'vbn': 'confirmed', 'vbg': 'confirming'},
{'lemma': 'conflict', 'vbz': 'conflicts', 'vbd': 'conflicted', 'vbn': 'conflicted', 'vbg': 'conflicting'},
{'lemma': 'connect', 'vbz': 'connects', 'vbd': 'connected', 'vbn': 'connected', 'vbg': 'connecting'},
{'lemma': 'consent', 'vbz': 'consents', 'vbd': 'consented', 'vbn': 'consented', 'vbg': 'consenting'},
{'lemma': 'consider', 'vbz': 'considers', 'vbd': 'considered', 'vbn': 'considered', 'vbg': 'considering'},
{'lemma': 'consist', 'vbz': 'consists', 'vbd': 'consisted', 'vbn': 'consisted', 'vbg': 'consisting'},
{'lemma': 'constitute', 'vbz': 'constitutes', 'vbd': 'constituted', 'vbn': 'constituted', 'vbg': 'constituting'},
{'lemma': 'construct', 'vbz': 'constructs', 'vbd': 'constructed', 'vbn': 'constructed', 'vbg': 'constructing'},
{'lemma': 'consult', 'vbz': 'consults', 'vbd': 'consulted', 'vbn': 'consulted', 'vbg': 'consulting'},
{'lemma': 'contact', 'vbz': 'contacts', 'vbd': 'contacted', 'vbn': 'contacted', 'vbg': 'contacting'},
{'lemma': 'contain', 'vbz': 'contains', 'vbd': 'contained', 'vbn': 'contained', 'vbg': 'containing'},
{'lemma': 'content', 'vbz': 'contents', 'vbd': 'contented', 'vbn': 'contented', 'vbg': 'contenting'},
{'lemma': 'contest', 'vbz': 'contests', 'vbd': 'contested', 'vbn': 'contested', 'vbg': 'contesting'},
{'lemma': 'continue', 'vbz': 'continues', 'vbd': 'continued', 'vbn': 'continued', 'vbg': 'continuing'},
{'lemma': 'contract', 'vbz': 'contracts', 'vbd': 'contracted', 'vbn': 'contracted', 'vbg': 'contracting'},
{'lemma': 'contrast', 'vbz': 'contrasts', 'vbd': 'contrasted', 'vbn': 'contrasted', 'vbg': 'contrasting'},
{'lemma': 'contribute', 'vbz': 'contributes', 'vbd': 'contributed', 'vbn': 'contributed', 'vbg': 'contributing'},
{'lemma': 'control', 'vbz': 'controls', 'vbd': 'controled', 'vbn': 'controled', 'vbg': 'controling'},
{'lemma': 'convert', 'vbz': 'converts', 'vbd': 'converted', 'vbn': 'converted', 'vbg': 'converting'},
{'lemma': 'convince', 'vbz': 'convinces', 'vbd': 'convinced', 'vbn': 'convinced', 'vbg': 'convincing'},
{'lemma': 'cook', 'vbz': 'cooks', 'vbd': 'cooked', 'vbn': 'cooked', 'vbg': 'cooking'},
{'lemma': 'cool', 'vbz': 'cools', 'vbd': 'cooled', 'vbn': 'cooled', 'vbg': 'cooling'},
{'lemma': 'cope', 'vbz': 'copes', 'vbd': 'coped', 'vbn': 'coped', 'vbg': 'coping'},
{'lemma': 'copy', 'vbz': 'copies', 'vbd': 'copied', 'vbn': 'copied', 'vbg': 'copying'},
{'lemma': 'core', 'vbz': 'cores', 'vbd': 'cored', 'vbn': 'cored', 'vbg': 'coring'},
{'lemma': 'corner', 'vbz': 'corners', 'vbd': 'cornered', 'vbn': 'cornered', 'vbg': 'cornering'},
{'lemma': 'cost', 'vbz': 'costs', 'vbd': 'cost', 'vbn': 'cost', 'vbg': 'costing'},
{'lemma': 'cotton', 'vbz': 'cottons', 'vbd': 'cottoned', 'vbn': 'cottoned', 'vbg': 'cottoning'},
{'lemma': 'count', 'vbz': 'counts', 'vbd': 'counted', 'vbn': 'counted', 'vbg': 'counting'},
{'lemma': 'counter', 'vbz': 'counters', 'vbd': 'countered', 'vbn': 'countered', 'vbg': 'countering'},
{'lemma': 'couple', 'vbz': 'couples', 'vbd': 'coupled', 'vbn': 'coupled', 'vbg': 'coupling'},
{'lemma': 'course', 'vbz': 'courses', 'vbd': 'coursed', 'vbn': 'coursed', 'vbg': 'coursing'},
{'lemma': 'court', 'vbz': 'courts', 'vbd': 'courted', 'vbn': 'courted', 'vbg': 'courting'},
{'lemma': 'cover', 'vbz': 'covers', 'vbd': 'covered', 'vbn': 'covered', 'vbg': 'covering'},
{'lemma': 'cow', 'vbz': 'cows', 'vbd': 'cowed', 'vbn': 'cowed', 'vbg': 'cowing'},
{'lemma': 'crack', 'vbz': 'cracks', 'vbd': 'cracked', 'vbn': 'cracked', 'vbg': 'cracking'},
{'lemma': 'crash', 'vbz': 'crashes', 'vbd': 'crashed', 'vbn': 'crashed', 'vbg': 'crashing'},
{'lemma': 'create', 'vbz': 'creates', 'vbd': 'created', 'vbn': 'created', 'vbg': 'creating'},
{'lemma': 'credit', 'vbz': 'credits', 'vbd': 'credited', 'vbn': 'credited', 'vbg': 'crediting'},
{'lemma': 'crew', 'vbz': 'crews', 'vbd': 'crewed', 'vbn': 'crewed', 'vbg': 'crewing'},
{'lemma': 'criticize', 'vbz': 'criticizes', 'vbd': 'criticized', 'vbn': 'criticized', 'vbg': 'criticizing'},
{'lemma': 'crop', 'vbz': 'crops', 'vbd': 'cropped', 'vbn': 'cropped', 'vbg': 'cropping'},
{'lemma': 'cross', 'vbz': 'crosses', 'vbd': 'crossed', 'vbn': 'crossed', 'vbg': 'crossing'},
{'lemma': 'crowd', 'vbz': 'crowds', 'vbd': 'crowded', 'vbn': 'crowded', 'vbg': 'crowding'},
{'lemma': 'crown', 'vbz': 'crowns', 'vbd': 'crowned', 'vbn': 'crowned', 'vbg': 'crowning'},
{'lemma': 'cry', 'vbz': 'cries', 'vbd': 'cried', 'vbn': 'cried', 'vbg': 'crying'},
{'lemma': 'curtain', 'vbz': 'curtains', 'vbd': 'curtained', 'vbn': 'curtained', 'vbg': 'curtaining'},
{'lemma': 'curve', 'vbz': 'curves', 'vbd': 'curved', 'vbn': 'curved', 'vbg': 'curving'},
{'lemma': 'cushion', 'vbz': 'cushions', 'vbd': 'cushioned', 'vbn': 'cushioned', 'vbg': 'cushioning'},
{'lemma': 'cut', 'vbz': 'cuts', 'vbd': 'cut', 'vbn': 'cut', 'vbg': 'cutting'},
{'lemma': 'cycle', 'vbz': 'cycles', 'vbd': 'cycled', 'vbn': 'cycled', 'vbg': 'cycling'},
{'lemma': 'damage', 'vbz': 'damages', 'vbd': 'damaged', 'vbn': 'damaged', 'vbg': 'damaging'},
{'lemma': 'dance', 'vbz': 'dances', 'vbd': 'danced', 'vbn': 'danced', 'vbg': 'dancing'},
{'lemma': 'dare', 'vbz': 'dares', 'vbd': 'dared', 'vbn': 'dared', 'vbg': 'daring'},
{'lemma': 'date', 'vbz': 'dates', 'vbd': 'dated', 'vbn': 'dated', 'vbg': 'dating'},
{'lemma': 'deal', 'vbz': 'deals', 'vbd': 'dealt', 'vbn': 'dealt', 'vbg': 'dealing'},
{'lemma': 'debate', 'vbz': 'debates', 'vbd': 'debated', 'vbn': 'debated', 'vbg': 'debating'},
{'lemma': 'decide', 'vbz': 'decides', 'vbd': 'decided', 'vbn': 'decided', 'vbg': 'deciding'},
{'lemma': 'declare', 'vbz': 'declares', 'vbd': 'declared', 'vbn': 'declared', 'vbg': 'declaring'},
{'lemma': 'decline', 'vbz': 'declines', 'vbd': 'declined', 'vbn': 'declined', 'vbg': 'declining'},
{'lemma': 'defeat', 'vbz': 'defeats', 'vbd': 'defeated', 'vbn': 'defeated', 'vbg': 'defeating'},
{'lemma': 'defend', 'vbz': 'defends', 'vbd': 'defended', 'vbn': 'defended', 'vbg': 'defending'},
{'lemma': 'define', 'vbz': 'defines', 'vbd': 'defined', 'vbn': 'defined', 'vbg': 'defining'},
{'lemma': 'delay', 'vbz': 'delays', 'vbd': 'delayed', 'vbn': 'delayed', 'vbg': 'delaying'},
{'lemma': 'deliver', 'vbz': 'delivers', 'vbd': 'delivered', 'vbn': 'delivered', 'vbg': 'delivering'},
{'lemma': 'demand', 'vbz': 'demands', 'vbd': 'demanded', 'vbn': 'demanded', 'vbg': 'demanding'},
{'lemma': 'demonstrate', 'vbz': 'demonstrates', 'vbd': 'demonstrated', 'vbn': 'demonstrated', 'vbg': 'demonstrating'},
{'lemma': 'deny', 'vbz': 'denies', 'vbd': 'denied', 'vbn': 'denied', 'vbg': 'denying'},
{'lemma': 'depend', 'vbz': 'depends', 'vbd': 'depended', 'vbn': 'depended', 'vbg': 'depending'},
{'lemma': 'deposit', 'vbz': 'deposits', 'vbd': 'deposited', 'vbn': 'deposited', 'vbg': 'depositing'},
{'lemma': 'derive', 'vbz': 'derives', 'vbd': 'derived', 'vbn': 'derived', 'vbg': 'deriving'},
{'lemma': 'describe', 'vbz': 'describes', 'vbd': 'described', 'vbn': 'described', 'vbg': 'describing'},
{'lemma': 'desert', 'vbz': 'deserts', 'vbd': 'deserted', 'vbn': 'deserted', 'vbg': 'deserting'},
{'lemma': 'deserve', 'vbz': 'deserves', 'vbd': 'deserved', 'vbn': 'deserved', 'vbg': 'deserving'},
{'lemma': 'design', 'vbz': 'designs', 'vbd': 'designed', 'vbn': 'designed', 'vbg': 'designing'},
{'lemma': 'desire', 'vbz': 'desires', 'vbd': 'desired', 'vbn': 'desired', 'vbg': 'desiring'},
{'lemma': 'destroy', 'vbz': 'destroys', 'vbd': 'destroyed', 'vbn': 'destroyed', 'vbg': 'destroying'},
{'lemma': 'detail', 'vbz': 'details', 'vbd': 'detailed', 'vbn': 'detailed', 'vbg': 'detailing'},
{'lemma': 'detect', 'vbz': 'detects', 'vbd': 'detected', 'vbn': 'detected', 'vbg': 'detecting'},
{'lemma': 'determine', 'vbz': 'determines', 'vbd': 'determined', 'vbn': 'determined', 'vbg': 'determining'},
{'lemma': 'develop', 'vbz': 'develops', 'vbd': 'developed', 'vbn': 'developed', 'vbg': 'developing'},
{'lemma': 'diagram', 'vbz': 'diagrams', 'vbd': 'diagramed', 'vbn': 'diagramed', 'vbg': 'diagraming'},
{'lemma': 'die', 'vbz': 'dies', 'vbd': 'died', 'vbn': 'died', 'vbg': 'dying'},
{'lemma': 'differ', 'vbz': 'differs', 'vbd': 'differed', 'vbn': 'differed', 'vbg': 'differing'},
{'lemma': 'dig', 'vbz': 'digs', 'vbd': 'digged', 'vbn': 'digged', 'vbg': 'digging'},
{'lemma': 'direct', 'vbz': 'directs', 'vbd': 'directed', 'vbn': 'directed', 'vbg': 'directing'},
{'lemma': 'dirty', 'vbz': 'dirties', 'vbd': 'dirtied', 'vbn': 'dirtied', 'vbg': 'dirtying'},
{'lemma': 'disagree', 'vbz': 'disagrees', 'vbd': 'disagreed', 'vbn': 'disagreed', 'vbg': 'disagreing'},
{'lemma': 'disappear', 'vbz': 'disappears', 'vbd': 'disappeared', 'vbn': 'disappeared', 'vbg': 'disappearing'},
{'lemma': 'disappoint', 'vbz': 'disappoints', 'vbd': 'disappointed', 'vbn': 'disappointed', 'vbg': 'disappointing'},
{'lemma': 'discipline', 'vbz': 'disciplines', 'vbd': 'disciplined', 'vbn': 'disciplined', 'vbg': 'disciplining'},
{'lemma': 'discount', 'vbz': 'discounts', 'vbd': 'discounted', 'vbn': 'discounted', 'vbg': 'discounting'},
{'lemma': 'discover', 'vbz': 'discovers', 'vbd': 'discovered', 'vbn': 'discovered', 'vbg': 'discovering'},
{'lemma': 'discuss', 'vbz': 'discusses', 'vbd': 'discussed', 'vbn': 'discussed', 'vbg': 'discussing'},
{'lemma': 'dish', 'vbz': 'dishes', 'vbd': 'dished', 'vbn': 'dished', 'vbg': 'dishing'},
{'lemma': 'dismiss', 'vbz': 'dismisses', 'vbd': 'dismissed', 'vbn': 'dismissed', 'vbg': 'dismissing'},
{'lemma': 'display', 'vbz': 'displaies', 'vbd': 'displayed', 'vbn': 'displayed', 'vbg': 'displaying'},
{'lemma': 'dispute', 'vbz': 'disputes', 'vbd': 'disputed', 'vbn': 'disputed', 'vbg': 'disputing'},
{'lemma': 'distance', 'vbz': 'distances', 'vbd': 'distanced', 'vbn': 'distanced', 'vbg': 'distancing'},
{'lemma': 'distinguish', 'vbz': 'distinguishes', 'vbd': 'distinguished', 'vbn': 'distinguished', 'vbg': 'distinguishing'},
{'lemma': 'distribute', 'vbz': 'distributes', 'vbd': 'distributed', 'vbn': 'distributed', 'vbg': 'distributing'},
{'lemma': 'disturb', 'vbz': 'disturbs', 'vbd': 'disturbed', 'vbn': 'disturbed', 'vbg': 'disturbing'},
{'lemma': 'divide', 'vbz': 'divides', 'vbd': 'divided', 'vbn': 'divided', 'vbg': 'dividing'},
{'lemma': 'divorce', 'vbz': 'divorces', 'vbd': 'divorced', 'vbn': 'divorced', 'vbg': 'divorcing'},
{'lemma': 'do', 'vbz': 'does', 'vbd': 'did', 'vbn': 'done', 'vbg': 'doing'},
{'lemma': 'doctor', 'vbz': 'doctors', 'vbd': 'doctored', 'vbn': 'doctored', 'vbg': 'doctoring'},
{'lemma': 'document', 'vbz': 'documents', 'vbd': 'documented', 'vbn': 'documented', 'vbg': 'documenting'},
{'lemma': 'dominate', 'vbz': 'dominates', 'vbd': 'dominated', 'vbn': 'dominated', 'vbg': 'dominating'},
{'lemma': 'dot', 'vbz': 'dots', 'vbd': 'dotted', 'vbn': 'dotted', 'vbg': 'doting'},
{'lemma': 'double', 'vbz': 'doubles', 'vbd': 'doubled', 'vbn': 'doubled', 'vbg': 'doubling'},
{'lemma': 'doubt', 'vbz': 'doubts', 'vbd': 'doubted', 'vbn': 'doubted', 'vbg': 'doubting'},
{'lemma': 'drag', 'vbz': 'drags', 'vbd': 'dragged', 'vbn': 'dragged', 'vbg': 'draging'},
{'lemma': 'draw', 'vbz': 'draws', 'vbd': 'drew', 'vbn': 'drawn', 'vbg': 'drawing'},
{'lemma': 'drawing', 'vbz': 'drawings', 'vbd': 'drawinged', 'vbn': 'drawinged', 'vbg': 'drawinging'},
{'lemma': 'dream', 'vbz': 'dreams', 'vbd': 'dreamed,dreamt', 'vbn': 'dreamed,dreamt', 'vbg': 'dreaming'},
{'lemma': 'dress', 'vbz': 'dresses', 'vbd': 'dressed', 'vbn': 'dressed', 'vbg': 'dressing'},
{'lemma': 'drink', 'vbz': 'drinks', 'vbd': 'drank', 'vbn': 'drunk', 'vbg': 'drinking'},
{'lemma': 'drive', 'vbz': 'drives', 'vbd': 'drived', 'vbn': 'drived', 'vbg': 'driving'},
{'lemma': 'drop', 'vbz': 'drops', 'vbd': 'dropped', 'vbn': 'dropped', 'vbg': 'droping'},
{'lemma': 'drug', 'vbz': 'drugs', 'vbd': 'drugged', 'vbn': 'drugged', 'vbg': 'druging'},
{'lemma': 'dry', 'vbz': 'dries', 'vbd': 'dried', 'vbn': 'dried', 'vbg': 'drying'},
{'lemma': 'duck', 'vbz': 'ducks', 'vbd': 'ducked', 'vbn': 'ducked', 'vbg': 'ducking'},
{'lemma': 'dull', 'vbz': 'dulls', 'vbd': 'dulled', 'vbn': 'dulled', 'vbg': 'dulling'},
{'lemma': 'dump', 'vbz': 'dumps', 'vbd': 'dumpped', 'vbn': 'dumpped', 'vbg': 'dumping'},
{'lemma': 'dust', 'vbz': 'dusts', 'vbd': 'dusted', 'vbn': 'dusted', 'vbg': 'dusting'},
{'lemma': 'earn', 'vbz': 'earns', 'vbd': 'earned', 'vbn': 'earned', 'vbg': 'earning'},
{'lemma': 'earth', 'vbz': 'earths', 'vbd': 'earthed', 'vbn': 'earthed', 'vbg': 'earthing'},
{'lemma': 'ease', 'vbz': 'eases', 'vbd': 'eased', 'vbn': 'eased', 'vbg': 'easing'},
{'lemma': 'eat', 'vbz': 'eats', 'vbd': 'ate', 'vbn': 'eaten', 'vbg': 'eating'},
{'lemma': 'edge', 'vbz': 'edges', 'vbd': 'edged', 'vbn': 'edged', 'vbg': 'edging'},
{'lemma': 'effect', 'vbz': 'effects', 'vbd': 'effected', 'vbn': 'effected', 'vbg': 'effecting'},
{'lemma': 'egg', 'vbz': 'eggs', 'vbd': 'egged', 'vbn': 'egged', 'vbg': 'egging'},
{'lemma': 'elect', 'vbz': 'elects', 'vbd': 'elected', 'vbn': 'elected', 'vbg': 'electing'},
{'lemma': 'emerge', 'vbz': 'emerges', 'vbd': 'emerged', 'vbn': 'emerged', 'vbg': 'emerging'},
{'lemma': 'emphasize', 'vbz': 'emphasizes', 'vbd': 'emphasized', 'vbn': 'emphasized', 'vbg': 'emphasizing'},
{'lemma': 'employ', 'vbz': 'emploies', 'vbd': 'employed', 'vbn': 'employed', 'vbg': 'employing'},
{'lemma': 'empty', 'vbz': 'empties', 'vbd': 'emptied', 'vbn': 'emptied', 'vbg': 'emptying'},
{'lemma': 'enable', 'vbz': 'enables', 'vbd': 'enabled', 'vbn': 'enabled', 'vbg': 'enabling'},
{'lemma': 'encounter', 'vbz': 'encounters', 'vbd': 'encountered', 'vbn': 'encountered', 'vbg': 'encountering'},
{'lemma': 'encourage', 'vbz': 'encourages', 'vbd': 'encouraged', 'vbn': 'encouraged', 'vbg': 'encouraging'},
{'lemma': 'engage', 'vbz': 'engages', 'vbd': 'engaged', 'vbn': 'engaged', 'vbg': 'engaging'},
{'lemma': 'engineer', 'vbz': 'engineers', 'vbd': 'engineered', 'vbn': 'engineered', 'vbg': 'engineering'},
{'lemma': 'enhance', 'vbz': 'enhances', 'vbd': 'enhanced', 'vbn': 'enhanced', 'vbg': 'enhancing'},
{'lemma': 'enjoy', 'vbz': 'enjoys', 'vbd': 'enjoyed', 'vbn': 'enjoyed', 'vbg': 'enjoying'},
{'lemma': 'ensure', 'vbz': 'ensures', 'vbd': 'ensured', 'vbn': 'ensured', 'vbg': 'ensuring'},
{'lemma': 'enter', 'vbz': 'enters', 'vbd': 'entered', 'vbn': 'entered', 'vbg': 'entering'},
{'lemma': 'entitle', 'vbz': 'entitles', 'vbd': 'entitled', 'vbn': 'entitled', 'vbg': 'entitling'},
{'lemma': 'entrance', 'vbz': 'entrances', 'vbd': 'entranced', 'vbn': 'entranced', 'vbg': 'entrancing'},
{'lemma': 'equal', 'vbz': 'equals', 'vbd': 'equalled', 'vbn': 'equalled', 'vbg': 'equalling'},
{'lemma': 'escape', 'vbz': 'escapes', 'vbd': 'escaped', 'vbn': 'escaped', 'vbg': 'escaping'},
{'lemma': 'establish', 'vbz': 'establishes', 'vbd': 'established', 'vbn': 'established', 'vbg': 'establishing'},
{'lemma': 'estimate', 'vbz': 'estimates', 'vbd': 'estimated', 'vbn': 'estimated', 'vbg': 'estimating'},
{'lemma': 'examine', 'vbz': 'examines', 'vbd': 'examined', 'vbn': 'examined', 'vbg': 'examining'},
{'lemma': 'exchange', 'vbz': 'exchanges', 'vbd': 'exchanged', 'vbn': 'exchanged', 'vbg': 'exchanging'},
{'lemma': 'exclude', 'vbz': 'excludes', 'vbd': 'excluded', 'vbn': 'excluded', 'vbg': 'excluding'},
{'lemma': 'excuse', 'vbz': 'excuses', 'vbd': 'excused', 'vbn': 'excused', 'vbg': 'excusing'},
{'lemma': 'exist', 'vbz': 'exists', 'vbd': 'existed', 'vbn': 'existed', 'vbg': 'existing'},
{'lemma': 'exit', 'vbz': 'exits', 'vbd': 'exited', 'vbn': 'exited', 'vbg': 'exiting'},
{'lemma': 'expand', 'vbz': 'expands', 'vbd': 'expanded', 'vbn': 'expanded', 'vbg': 'expanding'},
{'lemma': 'expect', 'vbz': 'expects', 'vbd': 'expected', 'vbn': 'expected', 'vbg': 'expecting'},
{'lemma': 'experiment', 'vbz': 'experiments', 'vbd': 'experimented', 'vbn': 'experimented', 'vbg': 'experimenting'},
{'lemma': 'explain', 'vbz': 'explains', 'vbd': 'explained', 'vbn': 'explained', 'vbg': 'explaining'},
{'lemma': 'explore', 'vbz': 'explores', 'vbd': 'explored', 'vbn': 'explored', 'vbg': 'exploring'},
{'lemma': 'expose', 'vbz': 'exposes', 'vbd': 'exposed', 'vbn': 'exposed', 'vbg': 'exposing'},
{'lemma': 'express', 'vbz': 'expresses', 'vbd': 'expressed', 'vbn': 'expressed', 'vbg': 'expressing'},
{'lemma': 'extend', 'vbz': 'extends', 'vbd': 'extended', 'vbn': 'extended', 'vbg': 'extending'},
{'lemma': 'face', 'vbz': 'faces', 'vbd': 'faced', 'vbn': 'faced', 'vbg': 'facing'},
{'lemma': 'factor', 'vbz': 'factors', 'vbd': 'factored', 'vbn': 'factored', 'vbg': 'factoring'},
{'lemma': 'fail', 'vbz': 'fails', 'vbd': 'failed', 'vbn': 'failed', 'vbg': 'failing'},
{'lemma': 'fall', 'vbz': 'falls', 'vbd': 'falled', 'vbn': 'falled', 'vbg': 'falling'},
{'lemma': 'fan', 'vbz': 'fans', 'vbd': 'fanned', 'vbn': 'fanned', 'vbg': 'faning'},
{'lemma': 'fancy', 'vbz': 'fancies', 'vbd': 'fancied', 'vbn': 'fancied', 'vbg': 'fancying'},
{'lemma': 'farm', 'vbz': 'farms', 'vbd': 'farmed', 'vbn': 'farmed', 'vbg': 'farming'},
{'lemma': 'fashion', 'vbz': 'fashions', 'vbd': 'fashioned', 'vbn': 'fashioned', 'vbg': 'fashioning'},
{'lemma': 'fault', 'vbz': 'faults', 'vbd': 'faulted', 'vbn': 'faulted', 'vbg': 'faulting'},
{'lemma': 'favour', 'vbz': 'favours', 'vbd': 'favoured', 'vbn': 'favoured', 'vbg': 'favouring'},
{'lemma': 'fear', 'vbz': 'fears', 'vbd': 'feared', 'vbn': 'feared', 'vbg': 'fearing'},
{'lemma': 'feature', 'vbz': 'features', 'vbd': 'featured', 'vbn': 'featured', 'vbg': 'featuring'},
{'lemma': 'feed', 'vbz': 'feeds', 'vbd': 'fed', 'vbn': 'fed', 'vbg': 'feeding'},
{'lemma': 'feel', 'vbz': 'feels', 'vbd': 'felt', 'vbn': 'felt', 'vbg': 'feeling'},
{'lemma': 'fence', 'vbz': 'fences', 'vbd': 'fenced', 'vbn': 'fenced', 'vbg': 'fencing'},
{'lemma': 'fetch', 'vbz': 'fetches', 'vbd': 'fetched', 'vbn': 'fetched', 'vbg': 'fetching'},
{'lemma': 'field', 'vbz': 'fields', 'vbd': 'fielded', 'vbn': 'fielded', 'vbg': 'fielding'},
{'lemma': 'fight', 'vbz': 'fights', 'vbd': 'fought', 'vbn': 'fought', 'vbg': 'fighting'},
{'lemma': 'figure', 'vbz': 'figures', 'vbd': 'figured', 'vbn': 'figured', 'vbg': 'figuring'},
{'lemma': 'file', 'vbz': 'files', 'vbd': 'filed', 'vbn': 'filed', 'vbg': 'filing'},
{'lemma': 'fill', 'vbz': 'fills', 'vbd': 'filled', 'vbn': 'filled', 'vbg': 'filling'},
{'lemma': 'film', 'vbz': 'films', 'vbd': 'filmed', 'vbn': 'filmed', 'vbg': 'filming'},
{'lemma': 'find', 'vbz': 'finds', 'vbd': 'finded', 'vbn': 'finded', 'vbg': 'finding'},
{'lemma': 'finish', 'vbz': 'finishes', 'vbd': 'finished', 'vbn': 'finished', 'vbg': 'finishing'},
{'lemma': 'fire', 'vbz': 'fires', 'vbd': 'fired', 'vbn': 'fired', 'vbg': 'firing'},
{'lemma': 'firm', 'vbz': 'firms', 'vbd': 'firmed', 'vbn': 'firmed', 'vbg': 'firming'},
{'lemma': 'fish', 'vbz': 'fishes', 'vbd': 'fished', 'vbn': 'fished', 'vbg': 'fishing'},
{'lemma': 'fit', 'vbz': 'fits', 'vbd': 'fitted,fit', 'vbn': 'fitted,fit', 'vbg': 'fitting'},
{'lemma': 'fix', 'vbz': 'fixes', 'vbd': 'fixed', 'vbn': 'fixed', 'vbg': 'fixing'},
{'lemma': 'flash', 'vbz': 'flashes', 'vbd': 'flashed', 'vbn': 'flashed', 'vbg': 'flashing'},
{'lemma': 'flavour', 'vbz': 'flavours', 'vbd': 'flavoured', 'vbn': 'flavoured', 'vbg': 'flavouring'},
{'lemma': 'flesh', 'vbz': 'fleshes', 'vbd': 'fleshed', 'vbn': 'fleshed', 'vbg': 'fleshing'},
{'lemma': 'flood', 'vbz': 'floods', 'vbd': 'flooded', 'vbn': 'flooded', 'vbg': 'flooding'},
{'lemma': 'floor', 'vbz': 'floors', 'vbd': 'floored', 'vbn': 'floored', 'vbg': 'flooring'},
{'lemma': 'flow', 'vbz': 'flows', 'vbd': 'flew', 'vbn': 'flown', 'vbg': 'flowing'},
{'lemma': 'flower', 'vbz': 'flowers', 'vbd': 'flowered', 'vbn': 'flowered', 'vbg': 'flowering'},
{'lemma': 'fly', 'vbz': 'flies', 'vbd': 'flied', 'vbn': 'flied', 'vbg': 'flying'},
{'lemma': 'focus', 'vbz': 'focuses', 'vbd': 'focused', 'vbn': 'focused', 'vbg': 'focusing'},
{'lemma': 'fold', 'vbz': 'folds', 'vbd': 'folded', 'vbn': 'folded', 'vbg': 'folding'},
{'lemma': 'follow', 'vbz': 'follows', 'vbd': 'followed', 'vbn': 'followed', 'vbg': 'following'},
{'lemma': 'force', 'vbz': 'forces', 'vbd': 'forced', 'vbn': 'forced', 'vbg': 'forcing'},
{'lemma': 'forest', 'vbz': 'forests', 'vbd': 'forested', 'vbn': 'forested', 'vbg': 'foresting'},
{'lemma': 'forget', 'vbz': 'forgets', 'vbd': 'forgot', 'vbn': 'forgotten', 'vbg': 'forgeting'},
{'lemma': 'forgive', 'vbz': 'forgives', 'vbd': 'forgave', 'vbn': 'forgiven', 'vbg': 'forgiving'},
{'lemma': 'fork', 'vbz': 'forks', 'vbd': 'forked', 'vbn': 'forked', 'vbg': 'forking'},
{'lemma': 'form', 'vbz': 'forms', 'vbd': 'formed', 'vbn': 'formed', 'vbg': 'forming'},
{'lemma': 'forward', 'vbz': 'forwards', 'vbd': 'forwarded', 'vbn': 'forwarded', 'vbg': 'forwarding'},
{'lemma': 'free', 'vbz': 'frees', 'vbd': 'freed', 'vbn': 'freed', 'vbg': 'freing'},
{'lemma': 'freeze', 'vbz': 'freezes', 'vbd': 'freezed', 'vbn': 'freezed', 'vbg': 'freezing'},
{'lemma': 'front', 'vbz': 'fronts', 'vbd': 'fronted', 'vbn': 'fronted', 'vbg': 'fronting'},
{'lemma': 'fruit', 'vbz': 'fruits', 'vbd': 'fruited', 'vbn': 'fruited', 'vbg': 'fruiting'},
{'lemma': 'fry', 'vbz': 'fries', 'vbd': 'fried', 'vbn': 'fried', 'vbg': 'frying'},
{'lemma': 'fuel', 'vbz': 'fuels', 'vbd': 'fueled', 'vbn': 'fueled', 'vbg': 'fueling'},
{'lemma': 'full', 'vbz': 'fulls', 'vbd': 'fulled', 'vbn': 'fulled', 'vbg': 'fulling'},
{'lemma': 'function', 'vbz': 'functions', 'vbd': 'functioned', 'vbn': 'functioned', 'vbg': 'functioning'},
{'lemma': 'fund', 'vbz': 'funds', 'vbd': 'funded', 'vbn': 'funded', 'vbg': 'funding'},
{'lemma': 'fuss', 'vbz': 'fusses', 'vbd': 'fussed', 'vbn': 'fussed', 'vbg': 'fussing'},
{'lemma': 'gain', 'vbz': 'gains', 'vbd': 'gained', 'vbn': 'gained', 'vbg': 'gaining'},
{'lemma': 'gang', 'vbz': 'gangs', 'vbd': 'ganged', 'vbn': 'ganged', 'vbg': 'ganging'},
{'lemma': 'garage', 'vbz': 'garages', 'vbd': 'garaged', 'vbn': 'garaged', 'vbg': 'garaging'},
{'lemma': 'garden', 'vbz': 'gardens', 'vbd': 'gardened', 'vbn': 'gardened', 'vbg': 'gardening'},
{'lemma': 'gas', 'vbz': 'gases', 'vbd': 'gassed', 'vbn': 'gassed', 'vbg': 'gasing'},
{'lemma': 'gather', 'vbz': 'gathers', 'vbd': 'gathered', 'vbn': 'gathered', 'vbg': 'gathering'},
{'lemma': 'generate', 'vbz': 'generates', 'vbd': 'generated', 'vbn': 'generated', 'vbg': 'generating'},
{'lemma': 'get', 'vbz': 'gets', 'vbd': 'got', 'vbn': 'gotten', 'vbg': 'getting'},
{'lemma': 'give', 'vbz': 'gives', 'vbd': 'gave', 'vbn': 'given', 'vbg': 'giving'},
{'lemma': 'glance', 'vbz': 'glances', 'vbd': 'glanced', 'vbn': 'glanced', 'vbg': 'glancing'},
{'lemma': 'glass', 'vbz': 'glasses', 'vbd': 'glassed', 'vbn': 'glassed', 'vbg': 'glassing'},
{'lemma': 'glove', 'vbz': 'gloves', 'vbd': 'gloved', 'vbn': 'gloved', 'vbg': 'gloving'},
{'lemma': 'go', 'vbz': 'goes', 'vbd': 'went', 'vbn': 'gone', 'vbg': 'going'},
{'lemma': 'govern', 'vbz': 'governs', 'vbd': 'governed', 'vbn': 'governed', 'vbg': 'governing'},
{'lemma': 'grab', 'vbz': 'grabs', 'vbd': 'grabbed', 'vbn': 'grabbed', 'vbg': 'grabbing'},
{'lemma': 'grade', 'vbz': 'grades', 'vbd': 'graded', 'vbn': 'graded', 'vbg': 'grading'},
{'lemma': 'grant', 'vbz': 'grants', 'vbd': 'granted', 'vbn': 'granted', 'vbg': 'granting'},
{'lemma': 'graph', 'vbz': 'graphs', 'vbd': 'graphed', 'vbn': 'graphed', 'vbg': 'graphing'},
{'lemma': 'grow', 'vbz': 'grows', 'vbd': 'grew', 'vbn': 'grown', 'vbg': 'growing'},
{'lemma': 'guarantee', 'vbz': 'guarantees', 'vbd': 'guaranteed', 'vbn': 'guaranteed', 'vbg': 'guaranteeing'},
{'lemma': 'guard', 'vbz': 'guards', 'vbd': 'guarded', 'vbn': 'guarded', 'vbg': 'guarding'},
{'lemma': 'guess', 'vbz': 'guesses', 'vbd': 'guessed', 'vbn': 'guessed', 'vbg': 'guessing'},
{'lemma': 'guide', 'vbz': 'guides', 'vbd': 'guided', 'vbn': 'guided', 'vbg': 'guiding'},
{'lemma': 'hand', 'vbz': 'hands', 'vbd': 'handed', 'vbn': 'handed', 'vbg': 'handing'},
{'lemma': 'handle', 'vbz': 'handles', 'vbd': 'handled', 'vbn': 'handled', 'vbg': 'handling'},
{'lemma': 'hang', 'vbz': 'hangs', 'vbd': 'hung', 'vbn': 'hung', 'vbg': 'hanging'},
{'lemma': 'happen', 'vbz': 'happens', 'vbd': 'happened', 'vbn': 'happened', 'vbg': 'happening'},
{'lemma': 'harm', 'vbz': 'harms', 'vbd': 'harmed', 'vbn': 'harmed', 'vbg': 'harming'},
{'lemma': 'hat', 'vbz': 'hats', 'vbd': 'hatted', 'vbn': 'hatted', 'vbg': 'hating'},
{'lemma': 'hate', 'vbz': 'hates', 'vbd': 'hated', 'vbn': 'hated', 'vbg': 'hating'},
{'lemma': 'have', 'vbz': 'has', 'vbd': 'had', 'vbn': 'had', 'vbg': 'having'},
{'lemma': 'hear', 'vbz': 'hears', 'vbd': 'heard', 'vbn': 'heard', 'vbg': 'hearing'},
{'lemma': 'heat', 'vbz': 'heats', 'vbd': 'heated', 'vbn': 'heated', 'vbg': 'heating'},
{'lemma': 'help', 'vbz': 'helps', 'vbd': 'helped', 'vbn': 'helped', 'vbg': 'helping'},
{'lemma': 'hesitate', 'vbz': 'hesitates', 'vbd': 'hesitated', 'vbn': 'hesitated', 'vbg': 'hesitating'},
{'lemma': 'hide', 'vbz': 'hides', 'vbd': 'hid', 'vbn': 'hidden', 'vbg': 'hiding'},
{'lemma': 'highlight', 'vbz': 'highlights', 'vbd': 'highlighted', 'vbn': 'highlighted', 'vbg': 'highlighting'},
{'lemma': 'hire', 'vbz': 'hires', 'vbd': 'hired', 'vbn': 'hired', 'vbg': 'hiring'},
{'lemma': 'hit', 'vbz': 'hits', 'vbd': 'hit', 'vbn': 'hit', 'vbg': 'hitting'},
{'lemma': 'hold', 'vbz': 'holds', 'vbd': 'held', 'vbn': 'held', 'vbg': 'holding'},
{'lemma': 'hole', 'vbz': 'holes', 'vbd': 'holed', 'vbn': 'holed', 'vbg': 'holing'},
{'lemma': 'honour', 'vbz': 'honours', 'vbd': 'honoured', 'vbn': 'honoured', 'vbg': 'honouring'},
{'lemma': 'hook', 'vbz': 'hooks', 'vbd': 'hooked', 'vbn': 'hooked', 'vbg': 'hooking'},
{'lemma': 'hope', 'vbz': 'hopes', 'vbd': 'hoped', 'vbn': 'hoped', 'vbg': 'hoping'},
{'lemma': 'horse', 'vbz': 'horses', 'vbd': 'horsed', 'vbn': 'horsed', 'vbg': 'hoping'},
{'lemma': 'host', 'vbz': 'hosts', 'vbd': 'hosted', 'vbn': 'hosted', 'vbg': 'hosting'},
{'lemma': 'house', 'vbz': 'houses', 'vbd': 'housed', 'vbn': 'housed', 'vbg': 'housing'},
{'lemma': 'hunt', 'vbz': 'hunts', 'vbd': 'hunted', 'vbn': 'hunted', 'vbg': 'hunting'},
{'lemma': 'hurry', 'vbz': 'hurries', 'vbd': 'hurried', 'vbn': 'hurried', 'vbg': 'hurrying'},
{'lemma': 'hurt', 'vbz': 'hurts', 'vbd': 'hurt', 'vbn': 'hurt', 'vbg': 'hurting'},
{'lemma': 'identify', 'vbz': 'identifies', 'vbd': 'identified', 'vbn': 'identified', 'vbg': 'identifying'},
{'lemma': 'ignore', 'vbz': 'ignores', 'vbd': 'ignored', 'vbn': 'ignored', 'vbg': 'ignoring'},
{'lemma': 'illustrate', 'vbz': 'illustrates', 'vbd': 'illustrated', 'vbn': 'illustrated', 'vbg': 'illustrating'},
{'lemma': 'imagine', 'vbz': 'imagines', 'vbd': 'imagined', 'vbn': 'imagined', 'vbg': 'imagining'},
{'lemma': 'impact', 'vbz': 'impacts', 'vbd': 'impacted', 'vbn': 'impacted', 'vbg': 'impacting'},
{'lemma': 'implement', 'vbz': 'implements', 'vbd': 'implemented', 'vbn': 'implemented', 'vbg': 'implementing'},
{'lemma': 'imply', 'vbz': 'implies', 'vbd': 'implied', 'vbn': 'implied', 'vbg': 'implying'},
{'lemma': 'import', 'vbz': 'imports', 'vbd': 'imported', 'vbn': 'imported', 'vbg': 'importing'},
{'lemma': 'impose', 'vbz': 'imposses', 'vbd': 'imposed', 'vbn': 'imposed', 'vbg': 'imposing'},
{'lemma': 'impress', 'vbz': 'impresses', 'vbd': 'impressed', 'vbn': 'impressed', 'vbg': 'impressing'},
{'lemma': 'improve', 'vbz': 'improves', 'vbd': 'improved', 'vbn': 'improved', 'vbg': 'improving'},
{'lemma': 'inch', 'vbz': 'inches', 'vbd': 'inched', 'vbn': 'inched', 'vbg': 'inching'},
{'lemma': 'include', 'vbz': 'includes', 'vbd': 'included', 'vbn': 'included', 'vbg': 'including'},
{'lemma': 'incorporate', 'vbz': 'incorporates', 'vbd': 'incorporated', 'vbn': 'incorporated', 'vbg': 'incorporating'},
{'lemma': 'increase', 'vbz': 'increases', 'vbd': 'increased', 'vbn': 'increased', 'vbg': 'increasing'},
{'lemma': 'index', 'vbz': 'indexes', 'vbd': 'indexed', 'vbn': 'indexed', 'vbg': 'indexing'},
{'lemma': 'indicate', 'vbz': 'indicates', 'vbd': 'indicated', 'vbn': 'indicated', 'vbg': 'indicating'},
{'lemma': 'influence', 'vbz': 'influences', 'vbd': 'influenced', 'vbn': 'influenced', 'vbg': 'influencing'},
{'lemma': 'inform', 'vbz': 'informs', 'vbd': 'informed', 'vbn': 'informed', 'vbg': 'informing'},
{'lemma': 'initial', 'vbz': 'initials', 'vbd': 'initialed', 'vbn': 'initialed', 'vbg': 'initialing'},
{'lemma': 'injure', 'vbz': 'injures', 'vbd': 'injured', 'vbn': 'injured', 'vbg': 'injuring'},
{'lemma': 'input', 'vbz': 'inputs', 'vbd': 'input', 'vbn': 'input', 'vbg': 'inputting'},
{'lemma': 'insist', 'vbz': 'insists', 'vbd': 'insisted', 'vbn': 'insisted', 'vbg': 'insisting'},
{'lemma': 'install', 'vbz': 'installs', 'vbd': 'installed', 'vbn': 'installed', 'vbg': 'installing'},
{'lemma': 'instance', 'vbz': 'instances', 'vbd': 'instanced', 'vbn': 'instanced', 'vbg': 'instancing'},
{'lemma': 'institute', 'vbz': 'institutes', 'vbd': 'instituted', 'vbn': 'instituted', 'vbg': 'instituting'},
{'lemma': 'intend', 'vbz': 'intends', 'vbd': 'intended', 'vbn': 'intended', 'vbg': 'intending'},
{'lemma': 'interest', 'vbz': 'interests', 'vbd': 'interested', 'vbn': 'interested', 'vbg': 'interesting'},
{'lemma': 'interpret', 'vbz': 'interprets', 'vbd': 'interpreted', 'vbn': 'interpreted', 'vbg': 'interpreting'},
{'lemma': 'interview', 'vbz': 'interviews', 'vbd': 'interviewed', 'vbn': 'interviewed', 'vbg': 'interviewing'},
{'lemma': 'introduce', 'vbz': 'introduces', 'vbd': 'introduced', 'vbn': 'introduced', 'vbg': 'introducing'},
{'lemma': 'invest', 'vbz': 'invests', 'vbd': 'invested', 'vbn': 'invested', 'vbg': 'investing'},
{'lemma': 'investigate', 'vbz': 'investigates', 'vbd': 'investigated', 'vbn': 'investigated', 'vbg': 'investigating'},
{'lemma': 'invite', 'vbz': 'invites', 'vbd': 'invited', 'vbn': 'invited', 'vbg': 'inviting'},
{'lemma': 'involve', 'vbz': 'involves', 'vbd': 'involved', 'vbn': 'involved', 'vbg': 'involving'},
{'lemma': 'iron', 'vbz': 'irons', 'vbd': 'ironed', 'vbn': 'ironed', 'vbg': 'ironing'},
{'lemma': 'issue', 'vbz': 'issues', 'vbd': 'issued', 'vbn': 'issued', 'vbg': 'issuing'},
{'lemma': 'jam', 'vbz': 'jams', 'vbd': 'jammed', 'vbn': 'jammed', 'vbg': 'jamming'},
{'lemma': 'join', 'vbz': 'joins', 'vbd': 'joined', 'vbn': 'joined', 'vbg': 'joining'},
{'lemma': 'joint', 'vbz': 'joints', 'vbd': 'jointed', 'vbn': 'jointed', 'vbg': 'jointing'},
{'lemma': 'joke', 'vbz': 'jokes', 'vbd': 'joked', 'vbn': 'joked', 'vbg': 'joking'},
{'lemma': 'judge', 'vbz': 'judges', 'vbd': 'judged', 'vbn': 'judged', 'vbg': 'judging'},
{'lemma': 'jump', 'vbz': 'jumps', 'vbd': 'jumped', 'vbn': 'jumped', 'vbg': 'jumping'},
{'lemma': 'justify', 'vbz': 'justifies', 'vbd': 'justified', 'vbn': 'justified', 'vbg': 'justifying'},
{'lemma': 'keep', 'vbz': 'keeps', 'vbd': 'kept', 'vbn': 'kept', 'vbg': 'keeping'},
{'lemma': 'kick', 'vbz': 'kicks', 'vbd': 'kicked', 'vbn': 'kicked', 'vbg': 'kicking'},
{'lemma': 'kill', 'vbz': 'kills', 'vbd': 'killed', 'vbn': 'killed', 'vbg': 'killing'},
{'lemma': 'kiss', 'vbz': 'kisses', 'vbd': 'kissed', 'vbn': 'kissed', 'vbg': 'kissing'},
{'lemma': 'kit', 'vbz': 'kits', 'vbd': 'kitted', 'vbn': 'kitted', 'vbg': 'kitting'},
{'lemma': 'knee', 'vbz': 'knees', 'vbd': 'kneed', 'vbn': 'kneed', 'vbg': 'kneeing'},
{'lemma': 'knock', 'vbz': 'knocks', 'vbd': 'knocked', 'vbn': 'knocked', 'vbg': 'knocking'},
{'lemma': 'know', 'vbz': 'knows', 'vbd': 'knew', 'vbn': 'known', 'vbg': 'knowing'},
{'lemma': 'label', 'vbz': 'labels', 'vbd': 'labeled', 'vbn': 'labeled', 'vbg': 'labelling'},
{'lemma': 'labour', 'vbz': 'labours', 'vbd': 'laboured', 'vbn': 'laboured', 'vbg': 'labouring'},
{'lemma': 'lack', 'vbz': 'lacks', 'vbd': 'lacked', 'vbn': 'lacked', 'vbg': 'lacking'},
{'lemma': 'ladder', 'vbz': 'ladders', 'vbd': 'laddered', 'vbn': 'laddered', 'vbg': 'laddering'},
{'lemma': 'lamb', 'vbz': 'lambs', 'vbd': 'lambed', 'vbn': 'lambed', 'vbg': 'lambing'},
{'lemma': 'land', 'vbz': 'lands', 'vbd': 'landed', 'vbn': 'landed', 'vbg': 'landing'},
{'lemma': 'landscape', 'vbz': 'landscapes', 'vbd': 'landscaped', 'vbn': 'landscaped', 'vbg': 'landscaping'},
{'lemma': 'last', 'vbz': 'lasts', 'vbd': 'lasted', 'vbn': 'lasted', 'vbg': 'lasting'},
{'lemma': 'laugh', 'vbz': 'laughs', 'vbd': 'laughed', 'vbn': 'laughed', 'vbg': 'laughing'},
{'lemma': 'launch', 'vbz': 'launches', 'vbd': 'launched', 'vbn': 'launched', 'vbg': 'launching'},
{'lemma': 'lay', 'vbz': 'lays', 'vbd': 'laid', 'vbn': 'laid', 'vbg': 'laying'},
{'lemma': 'layer', 'vbz': 'layers', 'vbd': 'layered', 'vbn': 'layered', 'vbg': 'layering'},
{'lemma': 'lead', 'vbz': 'leads', 'vbd': 'led', 'vbn': 'led', 'vbg': 'leading'},
{'lemma': 'leaf', 'vbz': 'leafs', 'vbd': 'leafed', 'vbn': 'leafed', 'vbg': 'leafing'},
{'lemma': 'lean', 'vbz': 'leans', 'vbd': 'leaned', 'vbn': 'leaned', 'vbg': 'leaning'},
{'lemma': 'learn', 'vbz': 'learns', 'vbd': 'learned,learnt', 'vbn': 'learned,learnt', 'vbg': 'learning'},
{'lemma': 'leave', 'vbz': 'leaves', 'vbd': 'left', 'vbn': 'left', 'vbg': 'leaving'},
{'lemma': 'lend', 'vbz': 'lends', 'vbd': 'lent', 'vbn': 'lent', 'vbg': 'lending'},
{'lemma': 'let', 'vbz': 'lets', 'vbd': 'let', 'vbn': 'let', 'vbg': 'leting'},
{'lemma': 'lick', 'vbz': 'licks', 'vbd': 'licked', 'vbn': 'licked', 'vbg': 'licking'},
{'lemma': 'lie', 'vbz': 'lies', 'vbd': 'lied', 'vbn': 'lied', 'vbg': 'lying'},
{'lemma': 'lift', 'vbz': 'lifts', 'vbd': 'lifted', 'vbn': 'lifted', 'vbg': 'lifting'},
{'lemma': 'light', 'vbz': 'lights', 'vbd': 'lighted', 'vbn': 'lighted', 'vbg': 'lighting'},
{'lemma': 'limit', 'vbz': 'limits', 'vbd': 'limited', 'vbn': 'limited', 'vbg': 'limiting'},
{'lemma': 'link', 'vbz': 'links', 'vbd': 'linked', 'vbn': 'linked', 'vbg': 'linking'},
{'lemma': 'list', 'vbz': 'lists', 'vbd': 'listed', 'vbn': 'listed', 'vbg': 'listing'},
{'lemma': 'listen', 'vbz': 'listens', 'vbd': 'listened', 'vbn': 'listened', 'vbg': 'listening'},
{'lemma': 'live', 'vbz': 'lives', 'vbd': 'lived', 'vbn': 'lived', 'vbg': 'living'},
{'lemma': 'locate', 'vbz': 'locates', 'vbd': 'located', 'vbn': 'located', 'vbg': 'locating'},
{'lemma': 'lock', 'vbz': 'locks', 'vbd': 'locked', 'vbn': 'locked', 'vbg': 'locking'},
{'lemma': 'look', 'vbz': 'looks', 'vbd': 'looked', 'vbn': 'looked', 'vbg': 'looking'},
{'lemma': 'lose', 'vbz': 'loses', 'vbd': 'lost', 'vbn': 'lost', 'vbg': 'losing'},
{'lemma': 'love', 'vbz': 'loves', 'vbd': 'loved', 'vbn': 'loved', 'vbg': 'loving'},
{'lemma': 'lower', 'vbz': 'lowers', 'vbd': 'lowered', 'vbn': 'lowered', 'vbg': 'lowering'},
{'lemma': 'mail', 'vbz': 'mails', 'vbd': 'mailed', 'vbn': 'mailed', 'vbg': 'mailing'},
{'lemma': 'maintain', 'vbz': 'maintains', 'vbd': 'maintained', 'vbn': 'maintained', 'vbg': 'maintaining'},
{'lemma': 'make', 'vbz': 'makes', 'vbd': 'made', 'vbn': 'made', 'vbg': 'making'},
{'lemma': 'manage', 'vbz': 'manages', 'vbd': 'managed', 'vbn': 'managed', 'vbg': 'managing'},
{'lemma': 'march', 'vbz': 'marches', 'vbd': 'marched', 'vbn': 'marched', 'vbg': 'marching'},
{'lemma': 'mark', 'vbz': 'marks', 'vbd': 'marked', 'vbn': 'marked', 'vbg': 'marking'},
{'lemma': 'marry', 'vbz': 'marries', 'vbd': 'married', 'vbn': 'married', 'vbg': 'marrying'},
{'lemma': 'match', 'vbz': 'matches', 'vbd': 'matched', 'vbn': 'matched', 'vbg': 'matching'},
{'lemma': 'matter', 'vbz': 'matters', 'vbd': 'mattered', 'vbn': 'mattered', 'vbg': 'mattering'},
{'lemma': 'mean', 'vbz': 'means', 'vbd': 'meaned', 'vbn': 'meaned', 'vbg': 'meaning'},
{'lemma': 'measure', 'vbz': 'measures', 'vbd': 'measured', 'vbn': 'measured', 'vbg': 'measuring'},
{'lemma': 'meet', 'vbz': 'meets', 'vbd': 'met', 'vbn': 'met', 'vbg': 'meeting'},
{'lemma': 'mention', 'vbz': 'mentions', 'vbd': 'mentioned', 'vbn': 'mentioned', 'vbg': 'mentioning'},
{'lemma': 'mess', 'vbz': 'messes', 'vbd': 'messed', 'vbn': 'messed', 'vbg': 'messing'},
{'lemma': 'mind', 'vbz': 'minds', 'vbd': 'minded', 'vbn': 'minded', 'vbg': 'minding'},
{'lemma': 'miss', 'vbz': 'misses', 'vbd': 'missed', 'vbn': 'missed', 'vbg': 'missing'},
{'lemma': 'mix', 'vbz': 'mixes', 'vbd': 'mixed', 'vbn': 'mixed', 'vbg': 'mixing'},
{'lemma': 'monitor', 'vbz': 'monitors', 'vbd': 'monitored', 'vbn': 'monitored', 'vbg': 'monitoring'},
{'lemma': 'move', 'vbz': 'moves', 'vbd': 'moved', 'vbn': 'moved', 'vbg': 'moving'},
{'lemma': 'name', 'vbz': 'names', 'vbd': 'named', 'vbn': 'named', 'vbg': 'naming'},
{'lemma': 'need', 'vbz': 'needs', 'vbd': 'needed', 'vbn': 'needed', 'vbg': 'needing'},
{'lemma': 'negotiate', 'vbz': 'negotiates', 'vbd': 'negotiated', 'vbn': 'negotiated', 'vbg': 'negotiating'},
{'lemma': 'nod', 'vbz': 'nods', 'vbd': 'nodded', 'vbn': 'nodded', 'vbg': 'nodding'},
{'lemma': 'note', 'vbz': 'notes', 'vbd': 'noted', 'vbn': 'noted', 'vbg': 'noting'},
{'lemma': 'notice', 'vbz': 'notices', 'vbd': 'noticed', 'vbn': 'noticed', 'vbg': 'noticing'},
{'lemma': 'object', 'vbz': 'objects', 'vbd': 'objected', 'vbn': 'objected', 'vbg': 'objecting'},
{'lemma': 'observe', 'vbz': 'observes', 'vbd': 'observed', 'vbn': 'observed', 'vbg': 'observing'},
{'lemma': 'obtain', 'vbz': 'obtains', 'vbd': 'obtained', 'vbn': 'obtained', 'vbg': 'obtaining'},
{'lemma': 'occupy', 'vbz': 'occupies', 'vbd': 'occupied', 'vbn': 'occupied', 'vbg': 'occupying'},
{'lemma': 'occur', 'vbz': 'occurs', 'vbd': 'occured', 'vbn': 'occured', 'vbg': 'occuring'},
{'lemma': 'offer', 'vbz': 'offers', 'vbd': 'offered', 'vbn': 'offered', 'vbg': 'offering'},
{'lemma': 'open', 'vbz': 'opens', 'vbd': 'opened', 'vbn': 'opened', 'vbg': 'opening'},
{'lemma': 'operate', 'vbz': 'operates', 'vbd': 'operated', 'vbn': 'operated', 'vbg': 'operating'},
{'lemma': 'oppose', 'vbz': 'opposes', 'vbd': 'opposed', 'vbn': 'opposed', 'vbg': 'opposing'},
{'lemma': 'order', 'vbz': 'orders', 'vbd': 'ordered', 'vbn': 'ordered', 'vbg': 'ordering'},
{'lemma': 'organize', 'vbz': 'organizes', 'vbd': 'organized', 'vbn': 'organized', 'vbg': 'organizing'},
{'lemma': 'overcome', 'vbz': 'overcomes', 'vbd': 'overcame', 'vbn': 'overcome', 'vbg': 'overcoming'},
{'lemma': 'owe', 'vbz': 'owes', 'vbd': 'owed', 'vbn': 'owed', 'vbg': 'owing'},
{'lemma': 'own', 'vbz': 'owns', 'vbd': 'owned', 'vbn': 'owned', 'vbg': 'owning'},
{'lemma': 'pack', 'vbz': 'packs', 'vbd': 'packed', 'vbn': 'packed', 'vbg': 'packing'},
{'lemma': 'paint', 'vbz': 'paints', 'vbd': 'painted', 'vbn': 'painted', 'vbg': 'painting'},
{'lemma': 'park', 'vbz': 'parks', 'vbd': 'parked', 'vbn': 'parked', 'vbg': 'parking'},
{'lemma': 'participate', 'vbz': 'participates', 'vbd': 'participated', 'vbn': 'participated', 'vbg': 'participating'},
{'lemma': 'pass', 'vbz': 'passes', 'vbd': 'passed', 'vbn': 'passed', 'vbg': 'passing'},
{'lemma': 'pause', 'vbz': 'pauses', 'vbd': 'paused', 'vbn': 'paused', 'vbg': 'pausing'},
{'lemma': 'pay', 'vbz': 'pays', 'vbd': 'paid', 'vbn': 'paid', 'vbg': 'paying'},
{'lemma': 'perceive', 'vbz': 'perceives', 'vbd': 'perceived', 'vbn': 'perceived', 'vbg': 'perceiving'},
{'lemma': 'perform', 'vbz': 'performs', 'vbd': 'performed', 'vbn': 'performed', 'vbg': 'performing'},
{'lemma': 'permit', 'vbz': 'permits', 'vbd': 'permitted', 'vbn': 'permitted', 'vbg': 'permiting'},
{'lemma': 'persuade', 'vbz': 'persuades', 'vbd': 'persuaded', 'vbn': 'persuaded', 'vbg': 'persuading'},
{'lemma': 'phone', 'vbz': 'phones', 'vbd': 'phoned', 'vbn': 'phoned', 'vbg': 'phoning'},
{'lemma': 'photocopy', 'vbz': 'photocopies', 'vbd': 'photocopied', 'vbn': 'photocopied', 'vbg': 'photocopying'},
{'lemma': 'pick', 'vbz': 'picks', 'vbd': 'picked', 'vbn': 'picked', 'vbg': 'picking'},
{'lemma': 'place', 'vbz': 'places', 'vbd': 'placed', 'vbn': 'placed', 'vbg': 'placing'},
{'lemma': 'plan', 'vbz': 'plans', 'vbd': 'planned', 'vbn': 'planned', 'vbg': 'planing'},
{'lemma': 'play', 'vbz': 'plays', 'vbd': 'played', 'vbn': 'played', 'vbg': 'playing'},
{'lemma': 'please', 'vbz': 'pleases', 'vbd': 'pleased', 'vbn': 'pleased', 'vbg': 'pleasing'},
{'lemma': 'point', 'vbz': 'points', 'vbd': 'pointed', 'vbn': 'pointed', 'vbg': 'pointing'},
{'lemma': 'pop', 'vbz': 'pops', 'vbd': 'popped', 'vbn': 'popped', 'vbg': 'popping'},
{'lemma': 'pose', 'vbz': 'poses', 'vbd': 'posed', 'vbn': 'posed', 'vbg': 'posing'},
{'lemma': 'possess', 'vbz': 'possesses', 'vbd': 'possessed', 'vbn': 'possessed', 'vbg': 'possessing'},
{'lemma': 'post', 'vbz': 'posts', 'vbd': 'posted', 'vbn': 'posted', 'vbg': 'posting'},
{'lemma': 'pour', 'vbz': 'pours', 'vbd': 'poured', 'vbn': 'poured', 'vbg': 'pouring'},
{'lemma': 'practise', 'vbz': 'practises', 'vbd': 'practised', 'vbn': 'practised', 'vbg': 'practising'},
{'lemma': 'pray', 'vbz': 'prays', 'vbd': 'prayed', 'vbn': 'prayed', 'vbg': 'praying'},
{'lemma': 'predict', 'vbz': 'predicts', 'vbd': 'predicted', 'vbn': 'predicted', 'vbg': 'predicting'},
{'lemma': 'prefer', 'vbz': 'prefers', 'vbd': 'prefered', 'vbn': 'prefered', 'vbg': 'prefering'},
{'lemma': 'prepare', 'vbz': 'prepares', 'vbd': 'prepared', 'vbn': 'prepared', 'vbg': 'preparing'},
{'lemma': 'present', 'vbz': 'presents', 'vbd': 'presented', 'vbn': 'presented', 'vbg': 'presenting'},
{'lemma': 'preserve', 'vbz': 'preserves', 'vbd': 'preserved', 'vbn': 'preserved', 'vbg': 'preserving'},
{'lemma': 'press', 'vbz': 'presses', 'vbd': 'pressed', 'vbn': 'pressed', 'vbg': 'pressing'},
{'lemma': 'presume', 'vbz': 'presumes', 'vbd': 'presumed', 'vbn': 'presumed', 'vbg': 'presuming'},
{'lemma': 'pretend', 'vbz': 'pretends', 'vbd': 'pretended', 'vbn': 'pretended', 'vbg': 'pretending'},
{'lemma': 'prevent', 'vbz': 'prevents', 'vbd': 'prevented', 'vbn': 'prevented', 'vbg': 'preventing'},
{'lemma': 'print', 'vbz': 'prints', 'vbd': 'printed', 'vbn': 'printed', 'vbg': 'printing'},
{'lemma': 'proceed', 'vbz': 'proceeds', 'vbd': 'proceded', 'vbn': 'proceded', 'vbg': 'proceeding'},
{'lemma': 'produce', 'vbz': 'produces', 'vbd': 'produced', 'vbn': 'produced', 'vbg': 'producing'},
{'lemma': 'promise', 'vbz': 'promises', 'vbd': 'promised', 'vbn': 'promised', 'vbg': 'promising'},
{'lemma': 'promote', 'vbz': 'promotes', 'vbd': 'promoted', 'vbn': 'promoted', 'vbg': 'promoting'},
{'lemma': 'propose', 'vbz': 'proposes', 'vbd': 'proposed', 'vbn': 'proposed', 'vbg': 'proposing'},
{'lemma': 'protect', 'vbz': 'protects', 'vbd': 'protected', 'vbn': 'protected', 'vbg': 'protecting'},
{'lemma': 'prove', 'vbz': 'proves', 'vbd': 'proved', 'vbn': 'proven', 'vbg': 'proving'},
{'lemma': 'provide', 'vbz': 'provides', 'vbd': 'provided', 'vbn': 'provided', 'vbg': 'providing'},
{'lemma': 'publish', 'vbz': 'publishes', 'vbd': 'published', 'vbn': 'published', 'vbg': 'publishing'},
{'lemma': 'pull', 'vbz': 'pulls', 'vbd': 'pulled', 'vbn': 'pulled', 'vbg': 'pulling'},
{'lemma': 'punch', 'vbz': 'punches', 'vbd': 'punched', 'vbn': 'punched', 'vbg': 'punching'},
{'lemma': 'purchase', 'vbz': 'purchases', 'vbd': 'purchased', 'vbn': 'purchased', 'vbg': 'purchasing'},
{'lemma': 'pursue', 'vbz': 'pursues', 'vbd': 'pursued', 'vbn': 'pursued', 'vbg': 'pursuing'},
{'lemma': 'push', 'vbz': 'pushes', 'vbd': 'pushed', 'vbn': 'pushed', 'vbg': 'pushing'},
{'lemma': 'put', 'vbz': 'puts', 'vbd': 'put', 'vbn': 'put', 'vbg': 'putting'},
{'lemma': 'qualify', 'vbz': 'qualifies', 'vbd': 'qualified', 'vbn': 'qualified', 'vbg': 'qualifying'},
{'lemma': 'question', 'vbz': 'questions', 'vbd': 'questioned', 'vbn': 'questioned', 'vbg': 'questioning'},
{'lemma': 'quit', 'vbz': 'quits', 'vbd': 'quit,quitted', 'vbn': 'quit,quitted', 'vbg': 'quiting'},
{'lemma': 'quote', 'vbz': 'quotes', 'vbd': 'quoted', 'vbn': 'quoted', 'vbg': 'quoting'},
{'lemma': 'race', 'vbz': 'races', 'vbd': 'raced', 'vbn': 'raced', 'vbg': 'racing'},
{'lemma': 'rail', 'vbz': 'rails', 'vbd': 'railed', 'vbn': 'railed', 'vbg': 'railing'},
{'lemma': 'rain', 'vbz': 'rains', 'vbd': 'rained', 'vbn': 'rained', 'vbg': 'raining'},
{'lemma': 'raise', 'vbz': 'raises', 'vbd': 'raised', 'vbn': 'raised', 'vbg': 'raising'},
{'lemma': 'range', 'vbz': 'ranges', 'vbd': 'ranged', 'vbn': 'ranged', 'vbg': 'ranging'},
{'lemma': 'rank', 'vbz': 'ranks', 'vbd': 'ranked', 'vbn': 'ranked', 'vbg': 'ranking'},
{'lemma': 'rate', 'vbz': 'rates', 'vbd': 'rated', 'vbn': 'rated', 'vbg': 'rating'},
{'lemma': 'reach', 'vbz': 'reaches', 'vbd': 'reached', 'vbn': 'reached', 'vbg': 'reaching'},
{'lemma': 'react', 'vbz': 'reacts', 'vbd': 'reacted', 'vbn': 'reacted', 'vbg': 'reacting'},
{'lemma': 'read', 'vbz': 'reads', 'vbd': 'read', 'vbn': 'read', 'vbg': 'reading'},
{'lemma': 'realize', 'vbz': 'realizes', 'vbd': 'realized', 'vbn': 'realized', 'vbg': 'realizing'},
{'lemma': 'reason', 'vbz': 'reasons', 'vbd': 'reasoned', 'vbn': 'reasoned', 'vbg': 'reasoning'},
{'lemma': 'recall', 'vbz': 'recalls', 'vbd': 'recalled', 'vbn': 'recalled', 'vbg': 'recalling'},
{'lemma': 'receipt', 'vbz': 'receipts', 'vbd': 'receipted', 'vbn': 'receipted', 'vbg': 'receipting'},
{'lemma': 'receive', 'vbz': 'receives', 'vbd': 'received', 'vbn': 'received', 'vbg': 'receiving'},
{'lemma': 'reckon', 'vbz': 'reckons', 'vbd': 'reckoned', 'vbn': 'reckoned', 'vbg': 'reckoning'},
{'lemma': 'recognize', 'vbz': 'recognizes', 'vbd': 'recognized', 'vbn': 'recognized', 'vbg': 'recognizing'},
{'lemma': 'recommend', 'vbz': 'recommends', 'vbd': 'recommended', 'vbn': 'recommended', 'vbg': 'recommending'},
{'lemma': 'record', 'vbz': 'records', 'vbd': 'recorded', 'vbn': 'recorded', 'vbg': 'recording'},
{'lemma': 'recover', 'vbz': 'recovers', 'vbd': 'recovered', 'vbn': 'recovered', 'vbg': 'recovering'},
{'lemma': 'reduce', 'vbz': 'reduces', 'vbd': 'reduced', 'vbn': 'reduced', 'vbg': 'reducing'},
{'lemma': 'refer', 'vbz': 'refers', 'vbd': 'referred', 'vbn': 'referred', 'vbg': 'refering'},
{'lemma': 'reflect', 'vbz': 'reflects', 'vbd': 'reflected', 'vbn': 'reflected', 'vbg': 'reflecting'},
{'lemma': 'reform', 'vbz': 'reforms', 'vbd': 'reformed', 'vbn': 'reformed', 'vbg': 'reforming'},
{'lemma': 'refuse', 'vbz': 'refuses', 'vbd': 'refused', 'vbn': 'refused', 'vbg': 'refusing'},
{'lemma': 'regard', 'vbz': 'regards', 'vbd': 'regarded', 'vbn': 'regarded', 'vbg': 'regarding'},
{'lemma': 'register', 'vbz': 'registers', 'vbd': 'registered', 'vbn': 'registered', 'vbg': 'registering'},
{'lemma': 'regret', 'vbz': 'regrets', 'vbd': 'regretted', 'vbn': 'regretted', 'vbg': 'regreting'},
{'lemma': 'reinforce', 'vbz': 'reinforces', 'vbd': 'reinforced', 'vbn': 'reinforced', 'vbg': 'reinforcing'},
{'lemma': 'reject', 'vbz': 'rejects', 'vbd': 'rejected', 'vbn': 'rejected', 'vbg': 'rejecting'},
{'lemma': 'relate', 'vbz': 'relates', 'vbd': 'related', 'vbn': 'related', 'vbg': 'relating'},
{'lemma': 'relax', 'vbz': 'relaxes', 'vbd': 'relaxed', 'vbn': 'relaxed', 'vbg': 'relaxing'},
{'lemma': 'release', 'vbz': 'releases', 'vbd': 'released', 'vbn': 'released', 'vbg': 'releasing'},
{'lemma': 'relieve', 'vbz': 'relieves', 'vbd': 'relieved', 'vbn': 'relieved', 'vbg': 'relieving'},
{'lemma': 'rely', 'vbz': 'relies', 'vbd': 'relied', 'vbn': 'relied', 'vbg': 'relying'},
{'lemma': 'remain', 'vbz': 'remains', 'vbd': 'remained', 'vbn': 'remained', 'vbg': 'remaining'},
{'lemma': 'remark', 'vbz': 'remarks', 'vbd': 'remarked', 'vbn': 'remarked', 'vbg': 'remarking'},
{'lemma': 'remember', 'vbz': 'remembers', 'vbd': 'remembered', 'vbn': 'remembered', 'vbg': 'remembering'},
{'lemma': 'remind', 'vbz': 'reminds', 'vbd': 'reminded', 'vbn': 'reminded', 'vbg': 'reminding'},
{'lemma': 'remove', 'vbz': 'removes', 'vbd': 'removed', 'vbn': 'removed', 'vbg': 'removing'},
{'lemma': 'rent', 'vbz': 'rents', 'vbd': 'rented', 'vbn': 'rented', 'vbg': 'renting'},
{'lemma': 'repair', 'vbz': 'repairs', 'vbd': 'repaired', 'vbn': 'repaired', 'vbg': 'repairing'},
{'lemma': 'repeat', 'vbz': 'repeats', 'vbd': 'repeated', 'vbn': 'repeated', 'vbg': 'repeating'},
{'lemma': 'replace', 'vbz': 'replaces', 'vbd': 'replaced', 'vbn': 'replaced', 'vbg': 'replacing'},
{'lemma': 'reply', 'vbz': 'replies', 'vbd': 'replied', 'vbn': 'replied', 'vbg': 'replying'},
{'lemma': 'report', 'vbz': 'reports', 'vbd': 'reported', 'vbn': 'reported', 'vbg': 'reporting'},
{'lemma': 'represent', 'vbz': 'represents', 'vbd': 'represented', 'vbn': 'represented', 'vbg': 'representing'},
{'lemma': 'request', 'vbz': 'requests', 'vbd': 'requested', 'vbn': 'requested', 'vbg': 'requesting'},
{'lemma': 'require', 'vbz': 'requires', 'vbd': 'required', 'vbn': 'required', 'vbg': 'requiring'},
{'lemma': 'rescue', 'vbz': 'rescues', 'vbd': 'rescued', 'vbn': 'rescued', 'vbg': 'rescuing'},
{'lemma': 'research', 'vbz': 'researches', 'vbd': 'researched', 'vbn': 'researched', 'vbg': 'researching'},
{'lemma': 'reserve', 'vbz': 'reserves', 'vbd': 'reserved', 'vbn': 'reserved', 'vbg': 'reserving'},
{'lemma': 'resign', 'vbz': 'resigns', 'vbd': 'resigned', 'vbn': 'resigned', 'vbg': 'resigning'},
{'lemma': 'resist', 'vbz': 'resists', 'vbd': 'resisted', 'vbn': 'resisted', 'vbg': 'resisting'},
{'lemma': 'resolve', 'vbz': 'resolves', 'vbd': 'resolved', 'vbn': 'resolved', 'vbg': 'resolving'},
{'lemma': 'resort', 'vbz': 'resorts', 'vbd': 'resorted', 'vbn': 'resorted', 'vbg': 'resorting'},
{'lemma': 'respect', 'vbz': 'respects', 'vbd': 'respected', 'vbn': 'respected', 'vbg': 'respecting'},
{'lemma': 'respond', 'vbz': 'responds', 'vbd': 'responded', 'vbn': 'responded', 'vbg': 'responding'},
{'lemma': 'rest', 'vbz': 'rests', 'vbd': 'rested', 'vbn': 'rested', 'vbg': 'resting'},
{'lemma': 'restore', 'vbz': 'restores', 'vbd': 'restored', 'vbn': 'restored', 'vbg': 'restoring'},
{'lemma': 'restrict', 'vbz': 'restricts', 'vbd': 'restricted', 'vbn': 'restricted', 'vbg': 'restricting'},
{'lemma': 'result', 'vbz': 'results', 'vbd': 'resulted', 'vbn': 'resulted', 'vbg': 'resulting'},
{'lemma': 'retain', 'vbz': 'retains', 'vbd': 'retained', 'vbn': 'retained', 'vbg': 'retaining'},
{'lemma': 'retire', 'vbz': 'retires', 'vbd': 'retired', 'vbn': 'retired', 'vbg': 'retiring'},
{'lemma': 'return', 'vbz': 'returns', 'vbd': 'returned', 'vbn': 'returned', 'vbg': 'returning'},
{'lemma': 'reveal', 'vbz': 'reveals', 'vbd': 'revealed', 'vbn': 'revealed', 'vbg': 'revealing'},
{'lemma': 'reverse', 'vbz': 'reverses', 'vbd': 'reversed', 'vbn': 'reversed', 'vbg': 'reversing'},
{'lemma': 'review', 'vbz': 'reviews', 'vbd': 'reviewed', 'vbn': 'reviewed', 'vbg': 'reviewing'},
{'lemma': 'reward', 'vbz': 'rewards', 'vbd': 'rewarded', 'vbn': 'rewarded', 'vbg': 'rewarding'},
{'lemma': 'ride', 'vbz': 'rides', 'vbd': 'rode', 'vbn': 'ridden', 'vbg': 'riding'},
{'lemma': 'ring', 'vbz': 'rings', 'vbd': 'ringed', 'vbn': 'ringed', 'vbg': 'ringing'},
{'lemma': 'rip', 'vbz': 'rips', 'vbd': 'ripped', 'vbn': 'ripped', 'vbg': 'ripping'},
{'lemma': 'rise', 'vbz': 'rises', 'vbd': 'rised', 'vbn': 'rised', 'vbg': 'rising'},
{'lemma': 'risk', 'vbz': 'risks', 'vbd': 'risked', 'vbn': 'risked', 'vbg': 'risking'},
{'lemma': 'rival', 'vbz': 'rivals', 'vbd': 'rivaled', 'vbn': 'rivaled', 'vbg': 'rivaling'},
{'lemma': 'rob', 'vbz': 'robs', 'vbd': 'robbed', 'vbn': 'robbed', 'vbg': 'robbing'},
{'lemma': 'rock', 'vbz': 'rocks', 'vbd': 'rocked', 'vbn': 'rocked', 'vbg': 'rocking'},
{'lemma': 'roll', 'vbz': 'rolls', 'vbd': 'rolled', 'vbn': 'rolled', 'vbg': 'rolling'},
{'lemma': 'roof', 'vbz': 'roofs', 'vbd': 'roofed', 'vbn': 'roofed', 'vbg': 'roofing'},
{'lemma': 'root', 'vbz': 'roots', 'vbd': 'rooted', 'vbn': 'rooted', 'vbg': 'rooting'},
{'lemma': 'rope', 'vbz': 'ropes', 'vbd': 'roped', 'vbn': 'roped', 'vbg': 'roping'},
{'lemma': 'route', 'vbz': 'routes', 'vbd': 'routed', 'vbn': 'routed', 'vbg': 'routing'},
{'lemma': 'row', 'vbz': 'rows', 'vbd': 'rowed', 'vbn': 'rowed', 'vbg': 'rowing'},
{'lemma': 'rub', 'vbz': 'rubs', 'vbd': 'rubbed', 'vbn': 'rubbed', 'vbg': 'rubbing'},
{'lemma': 'ruin', 'vbz': 'ruins', 'vbd': 'ruined', 'vbn': 'ruined', 'vbg': 'ruining'},
{'lemma': 'rule', 'vbz': 'rules', 'vbd': 'ruled', 'vbn': 'ruled', 'vbg': 'ruling'},
{'lemma': 'run', 'vbz': 'runs', 'vbd': 'runned', 'vbn': 'runned', 'vbg': 'runing'},
{'lemma': 'rush', 'vbz': 'rushes', 'vbd': 'rushed', 'vbn': 'rushed', 'vbg': 'rushing'},
{'lemma': 'sack', 'vbz': 'sacks', 'vbd': 'sacked', 'vbn': 'sacked', 'vbg': 'sacking'},
{'lemma': 'sail', 'vbz': 'sails', 'vbd': 'sailed', 'vbn': 'sailed', 'vbg': 'sailing'},
{'lemma': 'salt', 'vbz': 'salts', 'vbd': 'salted', 'vbn': 'salted', 'vbg': 'salting'},
{'lemma': 'sample', 'vbz': 'samples', 'vbd': 'sampled', 'vbn': 'sampled', 'vbg': 'sampling'},
{'lemma': 'sand', 'vbz': 'sands', 'vbd': 'sanded', 'vbn': 'sanded', 'vbg': 'sanding'},
{'lemma': 'sandwich', 'vbz': 'sandwiches', 'vbd': 'sandwiched', 'vbn': 'sandwiched', 'vbg': 'sandwiching'},
{'lemma': 'satisfy', 'vbz': 'satisfies', 'vbd': 'satisfied', 'vbn': 'satisfied', 'vbg': 'satisfying'},
{'lemma': 'sauce', 'vbz': 'sauces', 'vbd': 'sauced', 'vbn': 'sauced', 'vbg': 'saucing'},
{'lemma': 'save', 'vbz': 'saves', 'vbd': 'saved', 'vbn': 'saved', 'vbg': 'saving'},
{'lemma': 'say', 'vbz': 'says', 'vbd': 'said', 'vbn': 'said', 'vbg': 'saying'},
{'lemma': 'scale', 'vbz': 'scales', 'vbd': 'scaled', 'vbn': 'scaled', 'vbg': 'scaling'},
{'lemma': 'schedule', 'vbz': 'schedules', 'vbd': 'scheduled', 'vbn': 'scheduled', 'vbg': 'scheduling'},
{'lemma': 'scheme', 'vbz': 'schemes', 'vbd': 'schemed', 'vbn': 'schemed', 'vbg': 'scheming'},
{'lemma': 'score', 'vbz': 'scores', 'vbd': 'scored', 'vbn': 'scored', 'vbg': 'scoring'},
{'lemma': 'scratch', 'vbz': 'scratches', 'vbd': 'scratched', 'vbn': 'scratched', 'vbg': 'scratching'},
{'lemma': 'scream', 'vbz': 'screams', 'vbd': 'screamed', 'vbn': 'screamed', 'vbg': 'screaming'},
{'lemma': 'screen', 'vbz': 'screens', 'vbd': 'screened', 'vbn': 'screened', 'vbg': 'screening'},
{'lemma': 'script', 'vbz': 'scripts', 'vbd': 'scripted', 'vbn': 'scripted', 'vbg': 'scripting'},
{'lemma': 'seal', 'vbz': 'seals', 'vbd': 'sealed', 'vbn': 'sealed', 'vbg': 'sealing'},
{'lemma': 'search', 'vbz': 'searches', 'vbd': 'searched', 'vbn': 'searched', 'vbg': 'searching'},
{'lemma': 'season', 'vbz': 'seasons', 'vbd': 'seasoned', 'vbn': 'seasoned', 'vbg': 'seasoning'},
{'lemma': 'seat', 'vbz': 'seats', 'vbd': 'seated', 'vbn': 'seated', 'vbg': 'seating'},
{'lemma': 'second', 'vbz': 'seconds', 'vbd': 'seconded', 'vbn': 'seconded', 'vbg': 'seconding'},
{'lemma': 'section', 'vbz': 'sections', 'vbd': 'sectioned', 'vbn': 'sectioned', 'vbg': 'sectioning'},
{'lemma': 'secure', 'vbz': 'secures', 'vbd': 'secured', 'vbn': 'secured', 'vbg': 'securing'},
{'lemma': 'see', 'vbz': 'sees', 'vbd': 'saw', 'vbn': 'seen', 'vbg': 'seeing'},
{'lemma': 'seed', 'vbz': 'seeds', 'vbd': 'seeded', 'vbn': 'seeded', 'vbg': 'seeding'},
{'lemma': 'seek', 'vbz': 'seeks', 'vbd': 'sought', 'vbn': 'sought', 'vbg': 'seeking'},
{'lemma': 'seem', 'vbz': 'seems', 'vbd': 'seemed', 'vbn': 'seemed', 'vbg': 'seeming'},
{'lemma': 'seize', 'vbz': 'seizes', 'vbd': 'seized', 'vbn': 'seized', 'vbg': 'seizing'},
{'lemma': 'select', 'vbz': 'selects', 'vbd': 'selected', 'vbn': 'selected', 'vbg': 'selecting'},
{'lemma': 'sell', 'vbz': 'sells', 'vbd': 'sold', 'vbn': 'sold', 'vbg': 'selling'},
{'lemma': 'send', 'vbz': 'sends', 'vbd': 'sent', 'vbn': 'sent', 'vbg': 'sending'},
{'lemma': 'sense', 'vbz': 'senses', 'vbd': 'sensed', 'vbn': 'sensed', 'vbg': 'sensing'},
{'lemma': 'sentence', 'vbz': 'sentences', 'vbd': 'sentenced', 'vbn': 'sentenced', 'vbg': 'sentencing'},
{'lemma': 'sequence', 'vbz': 'sequences', 'vbd': 'sequenced', 'vbn': 'sequenced', 'vbg': 'sequencing'},
{'lemma': 'serve', 'vbz': 'serves', 'vbd': 'served', 'vbn': 'served', 'vbg': 'serving'},
{'lemma': 'service', 'vbz': 'services', 'vbd': 'serviced', 'vbn': 'serviced', 'vbg': 'servicing'},
{'lemma': 'set', 'vbz': 'sets', 'vbd': 'set', 'vbn': 'set', 'vbg': 'setting'},
{'lemma': 'settle', 'vbz': 'settles', 'vbd': 'settled', 'vbn': 'settled', 'vbg': 'settling'},
{'lemma': 'sew', 'vbz': 'sews', 'vbd': 'sewed', 'vbn': 'sewn', 'vbg': 'sewing'},
{'lemma': 'shadow', 'vbz': 'shadows', 'vbd': 'shadowed', 'vbn': 'shadowed', 'vbg': 'shadowing'},
{'lemma': 'shake', 'vbz': 'shakes', 'vbd': 'shook', 'vbn': 'shaken', 'vbg': 'shaking'},
{'lemma': 'shame', 'vbz': 'shames', 'vbd': 'shamed', 'vbn': 'shamed', 'vbg': 'shaming'},
{'lemma': 'shape', 'vbz': 'shapes', 'vbd': 'shaped', 'vbn': 'shaped', 'vbg': 'shaping'},
{'lemma': 'share', 'vbz': 'shares', 'vbd': 'shared', 'vbn': 'shared', 'vbg': 'sharing'},
{'lemma': 'shave', 'vbz': 'shaves', 'vbd': 'shaved', 'vbn': 'shaved', 'vbg': 'shaving'},
{'lemma': 'shed', 'vbz': 'sheds', 'vbd': 'shedded,shed', 'vbn': 'shedded,shed', 'vbg': 'sheding'},
{'lemma': 'shell', 'vbz': 'shells', 'vbd': 'shelled', 'vbn': 'shelled', 'vbg': 'shelling'},
{'lemma': 'shelter', 'vbz': 'shelters', 'vbd': 'sheltered', 'vbn': 'sheltered', 'vbg': 'sheltering'},
{'lemma': 'shift', 'vbz': 'shifts', 'vbd': 'shifted', 'vbn': 'shifted', 'vbg': 'shifting'},
{'lemma': 'shine', 'vbz': 'shines', 'vbd': 'shone', 'vbn': 'shone', 'vbg': 'shining'},
{'lemma': 'ship', 'vbz': 'ships', 'vbd': 'shipped', 'vbn': 'shipped', 'vbg': 'shipping'},
{'lemma': 'shock', 'vbz': 'shocks', 'vbd': 'shocked', 'vbn': 'shocked', 'vbg': 'shocking'},
{'lemma': 'shoot', 'vbz': 'shoots', 'vbd': 'shot', 'vbn': 'shot', 'vbg': 'shooting'},
{'lemma': 'shop', 'vbz': 'shops', 'vbd': 'shopped', 'vbn': 'shopped', 'vbg': 'shopping'},
{'lemma': 'shoulder', 'vbz': 'shoulders', 'vbd': 'shouldered', 'vbn': 'shouldered', 'vbg': 'shouldering'},
{'lemma': 'shout', 'vbz': 'shouts', 'vbd': 'shouted', 'vbn': 'shouted', 'vbg': 'shouting'},
{'lemma': 'shove', 'vbz': 'shoves', 'vbd': 'shoved', 'vbn': 'shoved', 'vbg': 'shoving'},
{'lemma': 'show', 'vbz': 'shows', 'vbd': 'showed', 'vbn': 'shown', 'vbg': 'showing'},
{'lemma': 'shower', 'vbz': 'showers', 'vbd': 'showered', 'vbn': 'showered', 'vbg': 'showering'},
{'lemma': 'shrug', 'vbz': 'shrugs', 'vbd': 'shrugged', 'vbn': 'shrugged', 'vbg': 'shruging'},
{'lemma': 'shut', 'vbz': 'shuts', 'vbd': 'shutted,shut', 'vbn': 'shutted,shut', 'vbg': 'shutting'},
{'lemma': 'sight', 'vbz': 'sights', 'vbd': 'sighted', 'vbn': 'sighted', 'vbg': 'sighting'},
{'lemma': 'sign', 'vbz': 'signs', 'vbd': 'signed', 'vbn': 'signed', 'vbg': 'signing'},
{'lemma': 'signal', 'vbz': 'signals', 'vbd': 'signaled', 'vbn': 'signaled', 'vbg': 'signaling'},
{'lemma': 'silver', 'vbz': 'silvers', 'vbd': 'silvered', 'vbn': 'silvered', 'vbg': 'silvering'},
{'lemma': 'sin', 'vbz': 'sins', 'vbd': 'sinned', 'vbn': 'sinned', 'vbg': 'sining'},
{'lemma': 'sing', 'vbz': 'sings', 'vbd': 'sang', 'vbn': 'sung', 'vbg': 'singing'},
{'lemma': 'sink', 'vbz': 'sinks', 'vbd': 'sank', 'vbn': 'sunk', 'vbg': 'sinking'},
{'lemma': 'sit', 'vbz': 'sits', 'vbd': 'sat', 'vbn': 'sat', 'vbg': 'sitting'},
{'lemma': 'site', 'vbz': 'sites', 'vbd': 'sited', 'vbn': 'sited', 'vbg': 'siting'},
{'lemma': 'size', 'vbz': 'sizes', 'vbd': 'sized', 'vbn': 'sized', 'vbg': 'sizing'},
{'lemma': 'skin', 'vbz': 'skins', 'vbd': 'skinned', 'vbn': 'skinned', 'vbg': 'skinning'},
{'lemma': 'skirt', 'vbz': 'skirts', 'vbd': 'skirted', 'vbn': 'skirted', 'vbg': 'skirting'},
{'lemma': 'sleep', 'vbz': 'sleeps', 'vbd': 'slept', 'vbn': 'slept', 'vbg': 'sleeping'},
{'lemma': 'slide', 'vbz': 'slides', 'vbd': 'slided', 'vbn': 'slided', 'vbg': 'sliding'},
{'lemma': 'slip', 'vbz': 'slips', 'vbd': 'slipped', 'vbn': 'slipped', 'vbg': 'slipping'},
{'lemma': 'slow', 'vbz': 'slows', 'vbd': 'slowed', 'vbn': 'slowed', 'vbg': 'slowing'},
{'lemma': 'smell', 'vbz': 'smells', 'vbd': 'smelled,smelt', 'vbn': 'smelled,smelt', 'vbg': 'smelling'},
{'lemma': 'smile', 'vbz': 'smiles', 'vbd': 'smiled', 'vbn': 'smiled', 'vbg': 'smiling'},
{'lemma': 'smoke', 'vbz': 'smokes', 'vbd': 'smoked', 'vbn': 'smoked', 'vbg': 'smoking'},
{'lemma': 'snap', 'vbz': 'snapps', 'vbd': 'snaped', 'vbn': 'snaped', 'vbg': 'snapping'},
{'lemma': 'solve', 'vbz': 'solves', 'vbd': 'solved', 'vbn': 'solved', 'vbg': 'solving'},
{'lemma': 'sort', 'vbz': 'sorts', 'vbd': 'sorted', 'vbn': 'sorted', 'vbg': 'sorting'},
{'lemma': 'sound', 'vbz': 'sounds', 'vbd': 'sounded', 'vbn': 'sounded', 'vbg': 'sounding'},
{'lemma': 'spare', 'vbz': 'spares', 'vbd': 'spared', 'vbn': 'spared', 'vbg': 'sparing'},
{'lemma': 'speak', 'vbz': 'speaks', 'vbd': 'spoke', 'vbn': 'spoken', 'vbg': 'speaking'},
{'lemma': 'specify', 'vbz': 'specifies', 'vbd': 'specified', 'vbn': 'specified', 'vbg': 'specifying'},
{'lemma': 'spell', 'vbz': 'spells', 'vbd': 'spelled,spelt', 'vbn': 'spelled,spelt', 'vbg': 'spelling'},
{'lemma': 'spend', 'vbz': 'spends', 'vbd': 'spent', 'vbn': 'spent', 'vbg': 'spending'},
{'lemma': 'spill', 'vbz': 'spills', 'vbd': 'spilled,spilt', 'vbn': 'spilled,spilt', 'vbg': 'spilling'},
{'lemma': 'spin', 'vbz': 'spins', 'vbd': 'spun', 'vbn': 'spun', 'vbg': 'spinning'},
{'lemma': 'split', 'vbz': 'splits', 'vbd': 'split', 'vbn': 'split', 'vbg': 'spliting'},
{'lemma': 'spoil', 'vbz': 'spoils', 'vbd': 'spoiled', 'vbn': 'spoiled', 'vbg': 'spoiling'},
{'lemma': 'spot', 'vbz': 'spots', 'vbd': 'spotted', 'vbn': 'spotted', 'vbg': 'spotting'},
{'lemma': 'spray', 'vbz': 'sprays', 'vbd': 'sprayed', 'vbn': 'sprayed', 'vbg': 'spraying'},
{'lemma': 'spread', 'vbz': 'spreads', 'vbd': 'spread', 'vbn': 'spread', 'vbg': 'spreading'},
{'lemma': 'squeeze', 'vbz': 'squeezes', 'vbd': 'squeezed', 'vbn': 'squeezed', 'vbg': 'squeezing'},
{'lemma': 'stamp', 'vbz': 'stamps', 'vbd': 'stampped', 'vbn': 'stampped', 'vbg': 'stamping'},
{'lemma': 'stand', 'vbz': 'stands', 'vbd': 'stood', 'vbn': 'stood', 'vbg': 'standing'},
{'lemma': 'stare', 'vbz': 'stares', 'vbd': 'stared', 'vbn': 'stared', 'vbg': 'staring'},
{'lemma': 'start', 'vbz': 'starts', 'vbd': 'started', 'vbn': 'started', 'vbg': 'starting'},
{'lemma': 'starve', 'vbz': 'starves', 'vbd': 'starved', 'vbn': 'starved', 'vbg': 'starving'},
{'lemma': 'state', 'vbz': 'states', 'vbd': 'stated', 'vbn': 'stated', 'vbg': 'stating'},
{'lemma': 'stay', 'vbz': 'stays', 'vbd': 'stayed', 'vbn': 'stayed', 'vbg': 'staying'},
{'lemma': 'steal', 'vbz': 'steals', 'vbd': 'stole', 'vbn': 'stolen', 'vbg': 'stealing'},
{'lemma': 'step', 'vbz': 'steps', 'vbd': 'stepped', 'vbn': 'stepped', 'vbg': 'steping'},
{'lemma': 'stick', 'vbz': 'sticks', 'vbd': 'stuck', 'vbn': 'stuck', 'vbg': 'sticking'},
{'lemma': 'stir', 'vbz': 'stirs', 'vbd': 'stirred', 'vbn': 'stirred', 'vbg': 'stiring'},
{'lemma': 'stop', 'vbz': 'stops', 'vbd': 'stopped', 'vbn': 'stopped', 'vbg': 'stopping'},
{'lemma': 'store', 'vbz': 'stores', 'vbd': 'stored', 'vbn': 'stored', 'vbg': 'storing'},
{'lemma': 'strengthen', 'vbz': 'strengthens', 'vbd': 'strengthened', 'vbn': 'strengthened', 'vbg': 'strengthening'},
{'lemma': 'stress', 'vbz': 'stresses', 'vbd': 'stressed', 'vbn': 'stressed', 'vbg': 'stressing'},
{'lemma': 'stretch', 'vbz': 'stretches', 'vbd': 'stretched', 'vbn': 'stretched', 'vbg': 'stretching'},
{'lemma': 'strike', 'vbz': 'strikes', 'vbd': 'struck', 'vbn': 'struck', 'vbg': 'striking'},
{'lemma': 'struggle', 'vbz': 'struggles', 'vbd': 'struggled', 'vbn': 'struggled', 'vbg': 'struggling'},
{'lemma': 'study', 'vbz': 'studies', 'vbd': 'studied', 'vbn': 'studied', 'vbg': 'studying'},
{'lemma': 'stuff', 'vbz': 'stuffs', 'vbd': 'stuffed', 'vbn': 'stuffed', 'vbg': 'stuffing'},
{'lemma': 'submit', 'vbz': 'submits', 'vbd': 'submitted', 'vbn': 'submitted', 'vbg': 'submiting'},
{'lemma': 'succeed', 'vbz': 'succeeds', 'vbd': 'succeeded', 'vbn': 'succeeded', 'vbg': 'succeeding'},
{'lemma': 'suck', 'vbz': 'sucks', 'vbd': 'sucked', 'vbn': 'sucked', 'vbg': 'sucking'},
{'lemma': 'suffer', 'vbz': 'suffers', 'vbd': 'suffered', 'vbn': 'suffered', 'vbg': 'suffering'},
{'lemma': 'suggest', 'vbz': 'suggests', 'vbd': 'suggested', 'vbn': 'suggested', 'vbg': 'suggesting'},
{'lemma': 'suit', 'vbz': 'suits', 'vbd': 'suited', 'vbn': 'suited', 'vbg': 'suiting'},
{'lemma': 'supply', 'vbz': 'supplies', 'vbd': 'supplied', 'vbn': 'supplied', 'vbg': 'supplying'},
{'lemma': 'support', 'vbz': 'supports', 'vbd': 'supported', 'vbn': 'supported', 'vbg': 'supporting'},
{'lemma': 'suppose', 'vbz': 'suppses', 'vbd': 'supposed', 'vbn': 'supposed', 'vbg': 'supposing'},
{'lemma': 'surround', 'vbz': 'surrounds', 'vbd': 'surrounded', 'vbn': 'surrounded', 'vbg': 'surrounding'},
{'lemma': 'survive', 'vbz': 'survives', 'vbd': 'survived', 'vbn': 'survived', 'vbg': 'surviving'},
{'lemma': 'suspect', 'vbz': 'suspects', 'vbd': 'suspected', 'vbn': 'suspected', 'vbg': 'suspecting'},
{'lemma': 'sustain', 'vbz': 'sustains', 'vbd': 'sustained', 'vbn': 'sustained', 'vbg': 'sustaining'},
{'lemma': 'swap', 'vbz': 'swaps', 'vbd': 'swapped', 'vbn': 'swapped', 'vbg': 'swapping'},
{'lemma': 'swear', 'vbz': 'swears', 'vbd': 'swore', 'vbn': 'sworn', 'vbg': 'swearing'},
{'lemma': 'sweep', 'vbz': 'sweeps', 'vbd': 'swept', 'vbn': 'swept', 'vbg': 'sweeping'},
{'lemma': 'swim', 'vbz': 'swims', 'vbd': 'swimmed,swam', 'vbn': 'swimmed,swum', 'vbg': 'swiming'},
{'lemma': 'swing', 'vbz': 'swings', 'vbd': 'swung', 'vbn': 'swung', 'vbg': 'swinging'},
{'lemma': 'switch', 'vbz': 'switches', 'vbd': 'switched', 'vbn': 'switched', 'vbg': 'switching'},
{'lemma': 'tackle', 'vbz': 'tackles', 'vbd': 'tackled', 'vbn': 'tackled', 'vbg': 'tackling'},
{'lemma': 'take', 'vbz': 'takes', 'vbd': 'took', 'vbn': 'taken', 'vbg': 'taking'},
{'lemma': 'talk', 'vbz': 'talks', 'vbd': 'talked', 'vbn': 'talked', 'vbg': 'talking'},
{'lemma': 'taste', 'vbz': 'tastes', 'vbd': 'tasted', 'vbn': 'tasted', 'vbg': 'tasting'},
{'lemma': 'teach', 'vbz': 'teaches', 'vbd': 'teached', 'vbn': 'teached', 'vbg': 'teaching'},
{'lemma': 'tear', 'vbz': 'tears', 'vbd': 'tore', 'vbn': 'torn', 'vbg': 'tearing'},
{'lemma': 'tell', 'vbz': 'tells', 'vbd': 'told', 'vbn': 'told', 'vbg': 'telling'},
{'lemma': 'tend', 'vbz': 'tends', 'vbd': 'tended', 'vbn': 'tended', 'vbg': 'tending'},
{'lemma': 'test', 'vbz': 'tests', 'vbd': 'tested', 'vbn': 'tested', 'vbg': 'testing'},
{'lemma': 'text', 'vbz': 'texts', 'vbd': 'texted', 'vbn': 'texted', 'vbg': 'texting'},
{'lemma': 'thank', 'vbz': 'thanks', 'vbd': 'thanked', 'vbn': 'thanked', 'vbg': 'thanking'},
{'lemma': 'think', 'vbz': 'thinks', 'vbd': 'thought', 'vbn': 'thought', 'vbg': 'thinking'},
{'lemma': 'threaten', 'vbz': 'threatens', 'vbd': 'threatened', 'vbn': 'threatened', 'vbg': 'threatening'},
{'lemma': 'throw', 'vbz': 'throws', 'vbd': 'threw', 'vbn': 'thrown', 'vbg': 'throwing'},
{'lemma': 'tie', 'vbz': 'ties', 'vbd': 'tied', 'vbn': 'tied', 'vbg': 'tying'},
{'lemma': 'tip', 'vbz': 'tips', 'vbd': 'tipped', 'vbn': 'tipped', 'vbg': 'tiping'},
{'lemma': 'touch', 'vbz': 'touches', 'vbd': 'touched', 'vbn': 'touched', 'vbg': 'touching'},
{'lemma': 'trade', 'vbz': 'trades', 'vbd': 'traded', 'vbn': 'traded', 'vbg': 'trading'},
{'lemma': 'transfer', 'vbz': 'transfers', 'vbd': 'transfered', 'vbn': 'transfered', 'vbg': 'transfering'},
{'lemma': 'transform', 'vbz': 'transforms', 'vbd': 'transformed', 'vbn': 'transformed', 'vbg': 'transforming'},
{'lemma': 'translate', 'vbz': 'translates', 'vbd': 'translated', 'vbn': 'translated', 'vbg': 'translating'},
{'lemma': 'travel', 'vbz': 'travels', 'vbd': 'travelled', 'vbn': 'travelled', 'vbg': 'traveling'},
{'lemma': 'treat', 'vbz': 'treats', 'vbd': 'treated', 'vbn': 'treated', 'vbg': 'treating'},
{'lemma': 'trust', 'vbz': 'trusts', 'vbd': 'trusted', 'vbn': 'trusted', 'vbg': 'trusting'},
{'lemma': 'try', 'vbz': 'tries', 'vbd': 'tried', 'vbn': 'tried', 'vbg': 'trying'},
{'lemma': 'turn', 'vbz': 'turns', 'vbd': 'turned', 'vbn': 'turned', 'vbg': 'turning'},
{'lemma': 'twist', 'vbz': 'twists', 'vbd': 'twisted', 'vbn': 'twisted', 'vbg': 'twisting'},
{'lemma': 'understand', 'vbz': 'understands', 'vbd': 'understood', 'vbn': 'understood', 'vbg': 'understanding'},
{'lemma': 'undertake', 'vbz': 'undertakes', 'vbd': 'undertook', 'vbn': 'undertaken', 'vbg': 'undertaking'},
{'lemma': 'upset', 'vbz': 'upsets', 'vbd': 'upset', 'vbn': 'upset', 'vbg': 'upseting'},
{'lemma': 'urge', 'vbz': 'urges', 'vbd': 'urged', 'vbn': 'urged', 'vbg': 'urging'},
{'lemma': 'use', 'vbz': 'uses', 'vbd': 'used', 'vbn': 'used', 'vbg': 'using'},
{'lemma': 'vacation', 'vbz': 'vacations', 'vbd': 'vacationed', 'vbn': 'vacationed', 'vbg': 'vacationing'},
{'lemma': 'vary', 'vbz': 'varies', 'vbd': 'varied', 'vbn': 'varied', 'vbg': 'varying'},
{'lemma': 'visit', 'vbz': 'visits', 'vbd': 'visited', 'vbn': 'visited', 'vbg': 'visiting'},
{'lemma': 'vote', 'vbz': 'votes', 'vbd': 'voted', 'vbn': 'voted', 'vbg': 'voting'},
{'lemma': 'wait', 'vbz': 'waits', 'vbd': 'waited', 'vbn': 'waited', 'vbg': 'waiting'},
{'lemma': 'wake', 'vbz': 'wakes', 'vbd': 'woke', 'vbn': 'waken', 'vbg': 'waking'},
{'lemma': 'walk', 'vbz': 'walks', 'vbd': 'walked', 'vbn': 'walked', 'vbg': 'walking'},
{'lemma': 'wander', 'vbz': 'wanders', 'vbd': 'wandered', 'vbn': 'wandered', 'vbg': 'wandering'},
{'lemma': 'want', 'vbz': 'wants', 'vbd': 'wanted', 'vbn': 'wanted', 'vbg': 'wanting'},
{'lemma': 'warn', 'vbz': 'warns', 'vbd': 'warned', 'vbn': 'warned', 'vbg': 'warning'},
{'lemma': 'wash', 'vbz': 'washes', 'vbd': 'washed', 'vbn': 'washed', 'vbg': 'washing'},
{'lemma': 'waste', 'vbz': 'wastes', 'vbd': 'wasted', 'vbn': 'wasted', 'vbg': 'wasting'},
{'lemma': 'watch', 'vbz': 'watches', 'vbd': 'watched', 'vbn': 'watched', 'vbg': 'watching'},
{'lemma': 'wave', 'vbz': 'waves', 'vbd': 'waved', 'vbn': 'waved', 'vbg': 'waving'},
{'lemma': 'wear', 'vbz': 'wears', 'vbd': 'wore', 'vbn': 'worn', 'vbg': 'wearing'},
{'lemma': 'weigh', 'vbz': 'weighs', 'vbd': 'weighed', 'vbn': 'weighed', 'vbg': 'weighing'},
{'lemma': 'welcome', 'vbz': 'welcomes', 'vbd': 'welcomed', 'vbn': 'welcomed', 'vbg': 'welcoming'},
{'lemma': 'whisper', 'vbz': 'whispers', 'vbd': 'whispered', 'vbn': 'whispered', 'vbg': 'whispering'},
{'lemma': 'win', 'vbz': 'wins', 'vbd': 'won', 'vbn': 'won', 'vbg': 'winning'},
{'lemma': 'wind', 'vbz': 'winds', 'vbd': 'winded,wound', 'vbn': 'winded,wound', 'vbg': 'winding'},
{'lemma': 'wipe', 'vbz': 'wipes', 'vbd': 'wiped', 'vbn': 'wiped', 'vbg': 'wiping'},
{'lemma': 'wish', 'vbz': 'wishes', 'vbd': 'wished', 'vbn': 'wished', 'vbg': 'wishing'},
{'lemma': 'withdraw', 'vbz': 'withdraws', 'vbd': 'withdrew', 'vbn': 'withdrawn', 'vbg': 'withdrawing'},
{'lemma': 'wonder', 'vbz': 'wonders', 'vbd': 'wondered', 'vbn': 'wondered', 'vbg': 'wondering'},
{'lemma': 'work', 'vbz': 'works', 'vbd': 'worked', 'vbn': 'worked', 'vbg': 'working'},
{'lemma': 'worry', 'vbz': 'worries', 'vbd': 'worried', 'vbn': 'worried', 'vbg': 'worrying'},
{'lemma': 'wound', 'vbz': 'wounds', 'vbd': 'wounded', 'vbn': 'wounded', 'vbg': 'wounding'},
{'lemma': 'wrap', 'vbz': 'wraps', 'vbd': 'wraped', 'vbn': 'wraped', 'vbg': 'wrapping'},
{'lemma': 'write', 'vbz': 'writes', 'vbd': 'wrote', 'vbn': 'written', 'vbg': 'writing'},]

#print (verbform)

def init_redis():
	import redis,json
	r = redis.Redis(host='dev.werror.com',port=8008, decode_responses=True)
	for v in verbform: 
		r.sadd('corpus:verbs', v['lemma'])
	print ("fniished")

if __name__ == '__main__':
	init_redis()


#!/usr/bin/env python
#-*- coding:utf-8 -*-
 
#############################################
# File Name: setup.py
# Author: cikuu
# Mail: info@cikuu.com
# Created Time: 2022-2-13
#############################################
 
from setuptools import setup, find_packages
 
setup(
  name = "cikuu",
  version = "2022.3.7",
  keywords = ("pip"),
  description = "cikuu tools",
  long_description = "cikuu tools, commonly used",
  license = "MIT Licence",
 
  url = "http://www.cikuu.com",
  author = "cikuu",
  author_email = "info@cikuu.com",
 
  packages = find_packages(),
  include_package_data = True,
  platforms = "any",
  install_requires = ["lmdb","fire","redis","elasticsearch","pymysql","pika"]
)
